<?php
/**
* Smarty Internal Plugin Templateparser
*
* This is the template parser.
* It is generated from the internal.templateparser.y file
* @package Smarty
* @subpackage Compiler
* @author Uwe Tews
*/

/**
 * This can be used to store both the string representation of
 * a token, and any useful meta-data associated with the token.
 *
 * meta-data should be stored as an array
 */
class TP_yyToken implements ArrayAccess
{
    public $string = '';
    public $metadata = array();

    function __construct($s, $m = array())
    {
        if ($s instanceof TP_yyToken) {
            $this->string = $s->string;
            $this->metadata = $s->metadata;
        } else {
            $this->string = (string) $s;
            if ($m instanceof TP_yyToken) {
                $this->metadata = $m->metadata;
            } elseif (is_array($m)) {
                $this->metadata = $m;
            }
        }
    }

    function __toString()
    {
        return $this->_string;
    }

    function offsetExists($offset)
    {
        return isset($this->metadata[$offset]);
    }

    function offsetGet($offset)
    {
        return $this->metadata[$offset];
    }

    function offsetSet($offset, $value)
    {
        if ($offset === null) {
            if (isset($value[0])) {
                $x = ($value instanceof TP_yyToken) ?
                    $value->metadata : $value;
                $this->metadata = array_merge($this->metadata, $x);
                return;
            }
            $offset = count($this->metadata);
        }
        if ($value === null) {
            return;
        }
        if ($value instanceof TP_yyToken) {
            if ($value->metadata) {
                $this->metadata[$offset] = $value->metadata;
            }
        } elseif ($value) {
            $this->metadata[$offset] = $value;
        }
    }

    function offsetUnset($offset)
    {
        unset($this->metadata[$offset]);
    }
}

/** The following structure represents a single element of the
 * parser's stack.  Information stored includes:
 *
 *   +  The state number for the parser at this level of the stack.
 *
 *   +  The value of the token stored at this level of the stack.
 *      (In other words, the "major" token.)
 *
 *   +  The semantic value stored at this level of the stack.  This is
 *      the information used by the action routines in the grammar.
 *      It is sometimes called the "minor" token.
 */
class TP_yyStackEntry
{
    public $stateno;       /* The state-number */
    public $major;         /* The major token value.  This is the code
                     ** number for the token at this stack level */
    public $minor; /* The user-supplied minor token value.  This
                     ** is the value of the token  */
};

// code external to the class is included here

// declare_class is output here
#line 12 "internal.templateparser.y"
class Smarty_Internal_Templateparser#line 109 "internal.templateparser.php"
{
/* First off, code is included which follows the "include_class" declaration
** in the input file. */
#line 14 "internal.templateparser.y"

    // states whether the parse was successful or not
    public $successful = true;
    public $retvalue = 0;
    private $lex;
    private $internalError = false;

    function __construct($lex, $compiler) {
        // set instance object
        self::instance($this); 
        $this->lex = $lex;
        $this->compiler = $compiler;
        $this->smarty = $this->compiler->smarty;
        $this->template = $this->compiler->template;
        if ($this->template->security && isset($this->smarty->security_handler)) {
              $this->sec_obj = $this->smarty->security_policy;
        } else {
              $this->sec_obj = $this->smarty;
        }
        $this->cacher = $this->template->cacher_object; 
				$this->nocache = false;
				$this->prefix_code = array();
				$this->prefix_number = 0;
    }
    public static function &instance($new_instance = null)
    {
        static $instance = null;
        if (isset($new_instance) && is_object($new_instance))
            $instance = $new_instance;
        return $instance;
    }
    
#line 147 "internal.templateparser.php"

/* Next is all token values, as class constants
*/
/* 
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands. 
**
** Each symbol here is a terminal symbol in the grammar.
*/
    const TP_OTHER                          =  1;
    const TP_XML                            =  2;
    const TP_PHP                            =  3;
    const TP_SHORTTAGSTART                  =  4;
    const TP_SHORTTAGEND                    =  5;
    const TP_PHPSTART                       =  6;
    const TP_PHPEND                         =  7;
    const TP_COMMENTEND                     =  8;
    const TP_COMMENTSTART                   =  9;
    const TP_SINGLEQUOTE                    = 10;
    const TP_LITERALSTART                   = 11;
    const TP_LITERALEND                     = 12;
    const TP_LDELIMTAG                      = 13;
    const TP_RDELIMTAG                      = 14;
    const TP_LDELSLASH                      = 15;
    const TP_LDEL                           = 16;
    const TP_RDEL                           = 17;
    const TP_ISIN                           = 18;
    const TP_AS                             = 19;
    const TP_BOOLEAN                        = 20;
    const TP_NULL                           = 21;
    const TP_IDENTITY                       = 22;
    const TP_NONEIDENTITY                   = 23;
    const TP_EQUALS                         = 24;
    const TP_NOTEQUALS                      = 25;
    const TP_GREATEREQUAL                   = 26;
    const TP_LESSEQUAL                      = 27;
    const TP_GREATERTHAN                    = 28;
    const TP_LESSTHAN                       = 29;
    const TP_NOT                            = 30;
    const TP_LAND                           = 31;
    const TP_LOR                            = 32;
    const TP_LXOR                           = 33;
    const TP_ISODDBY                        = 34;
    const TP_ISNOTODDBY                     = 35;
    const TP_ISODD                          = 36;
    const TP_ISNOTODD                       = 37;
    const TP_ISEVENBY                       = 38;
    const TP_ISNOTEVENBY                    = 39;
    const TP_ISEVEN                         = 40;
    const TP_ISNOTEVEN                      = 41;
    const TP_ISDIVBY                        = 42;
    const TP_ISNOTDIVBY                     = 43;
    const TP_OPENP                          = 44;
    const TP_CLOSEP                         = 45;
    const TP_OPENB                          = 46;
    const TP_CLOSEB                         = 47;
    const TP_PTR                            = 48;
    const TP_APTR                           = 49;
    const TP_EQUAL                          = 50;
    const TP_INTEGER                        = 51;
    const TP_INCDEC                         = 52;
    const TP_UNIMATH                        = 53;
    const TP_MATH                           = 54;
    const TP_DOLLAR                         = 55;
    const TP_COLON                          = 56;
    const TP_DOUBLECOLON                    = 57;
    const TP_SEMICOLON                      = 58;
    const TP_AT                             = 59;
    const TP_HATCH                          = 60;
    const TP_QUOTE                          = 61;
    const TP_BACKTICK                       = 62;
    const TP_VERT                           = 63;
    const TP_DOT                            = 64;
    const TP_COMMA                          = 65;
    const TP_ANDSYM                         = 66;
    const TP_ID                             = 67;
    const TP_SPACE                          = 68;
    const TP_INSTANCEOF                     = 69;
    const YY_NO_ACTION = 448;
    const YY_ACCEPT_ACTION = 447;
    const YY_ERROR_ACTION = 446;

/* Next are that tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N < self::YYNSTATE                              Shift N.  That is,
**                                                        push the lookahead
**                                                        token onto the stack
**                                                        and goto state N.
**
**   self::YYNSTATE <= N < self::YYNSTATE+self::YYNRULE   Reduce by rule N-YYNSTATE.
**
**   N == self::YYNSTATE+self::YYNRULE                    A syntax error has occurred.
**
**   N == self::YYNSTATE+self::YYNRULE+1                  The parser accepts its
**                                                        input. (and concludes parsing)
**
**   N == self::YYNSTATE+self::YYNRULE+2                  No such action.  Denotes unused
**                                                        slots in the yy_action[] table.
**
** The action table is constructed as a single large static array $yy_action.
** Given state S and lookahead X, the action is computed as
**
**      self::$yy_action[self::$yy_shift_ofst[S] + X ]
**
** If the index value self::$yy_shift_ofst[S]+X is out of range or if the value
** self::$yy_lookahead[self::$yy_shift_ofst[S]+X] is not equal to X or if
** self::$yy_shift_ofst[S] is equal to self::YY_SHIFT_USE_DFLT, it means that
** the action is not in the table and that self::$yy_default[S] should be used instead.  
**
** The formula above is for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the static $yy_reduce_ofst array is used in place of
** the static $yy_shift_ofst array and self::YY_REDUCE_USE_DFLT is used in place of
** self::YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  self::$yy_action        A single table containing all actions.
**  self::$yy_lookahead     A table containing the lookahead for each entry in
**                          yy_action.  Used to detect hash collisions.
**  self::$yy_shift_ofst    For each state, the offset into self::$yy_action for
**                          shifting terminals.
**  self::$yy_reduce_ofst   For each state, the offset into self::$yy_action for
**                          shifting non-terminals after a reduce.
**  self::$yy_default       Default action for each state.
*/
    const YY_SZ_ACTTAB = 1162;
static public $yy_action = array(
 /*     0 */    56,   27,  193,   56,  281,  153,   25,   39,  153,   25,
 /*    10 */   210,  206,  276,  210,  206,  242,  244,   60,  158,  245,
 /*    20 */     4,   62,   72,   67,  165,   69,   46,  230,  236,  153,
 /*    30 */    25,   19,  275,  167,    5,  130,   12,   23,  200,   12,
 /*    40 */   192,  161,  222,   35,  161,   66,   35,  186,   62,  231,
 /*    50 */    46,   40,  203,   46,   40,  157,  235,  137,  139,   14,
 /*    60 */   134,  153,   18,  157,  227,   30,  262,  259,  260,   10,
 /*    70 */     2,  266,  263,   11,    7,  264,  265,    3,    6,  139,
 /*    80 */   196,  447,   51,  185,  234,   31,   56,   39,   57,   56,
 /*    90 */    27,  153,   25,  148,  153,   25,  210,  206,  277,  210,
 /*   100 */   206,  142,   93,   42,  269,   34,    4,  197,   43,  249,
 /*   110 */   250,  254,  255,  252,  248,  256,  253,  108,  269,  129,
 /*   120 */     5,  208,   12,   23,   29,   12,  204,  161,  226,   35,
 /*   130 */   161,   58,   35,  231,   66,   91,   46,   40,  282,   46,
 /*   140 */    40,  203,  270,  133,  229,  139,   41,   16,  227,  157,
 /*   150 */   139,  269,  262,  259,  260,   10,    2,  266,  263,   11,
 /*   160 */     7,  264,  265,    3,    6,  257,  262,  259,  260,   10,
 /*   170 */     2,  266,  263,   11,    7,  264,  265,    3,    6,   56,
 /*   180 */   261,  320,  184,  139,  153,   25,   27,  201,  139,  210,
 /*   190 */   206,  262,  259,  260,   10,    2,  266,  263,   11,    7,
 /*   200 */   264,  265,    3,    6,  110,   31,   56,  199,   13,   27,
 /*   210 */   106,  153,   25,   23,   22,   12,  210,  206,  284,  283,
 /*   220 */   161,  112,   35,   42,   66,  178,  205,  118,   56,   46,
 /*   230 */    40,   36,  320,  153,   25,  231,  137,  203,  210,  206,
 /*   240 */    23,  272,   12,   20,  219,   72,   48,  161,  114,   35,
 /*   250 */   227,   62,  171,  267,  268,   27,   46,   40,  214,  207,
 /*   260 */   203,  198,   23,  140,   12,  222,  231,  284,  283,  161,
 /*   270 */   237,   35,  272,   62,  129,   14,   72,  157,   46,   40,
 /*   280 */    36,  227,   56,  151,  274,  141,  183,  153,   25,  214,
 /*   290 */   207,  195,  210,  206,    8,  272,  222,  123,  171,   72,
 /*   300 */   216,  119,  209,  157,   56,   53,  203,  218,  278,  153,
 /*   310 */    25,  129,  214,  207,  210,  206,   23,  272,   12,  222,
 /*   320 */   179,   72,  139,  161,   13,   35,   15,   66,  177,  213,
 /*   330 */   223,   27,   46,   40,  214,  207,   21,  112,   23,   41,
 /*   340 */    12,  222,  186,  139,  180,  161,  128,   35,    1,   66,
 /*   350 */   224,  182,  233,  234,   46,   40,  153,   18,  284,  283,
 /*   360 */   272,  135,   52,   13,   72,   20,  189,   74,  145,  136,
 /*   370 */    96,   36,  144,  175,   13,   89,  112,  214,  207,   28,
 /*   380 */    56,  226,  203,  166,  222,  153,   25,  112,   56,  258,
 /*   390 */   210,  206,  139,  153,   25,  225,  142,   32,  210,  206,
 /*   400 */   162,   56,  181,   43,  132,   62,  153,   25,   33,  147,
 /*   410 */    46,  210,  206,  100,   23,  131,   12,  168,  247,  231,
 /*   420 */   157,  161,   23,  280,  226,   62,  187,   72,  246,  161,
 /*   430 */    46,   40,  220,   62,  227,   23,   62,  140,   46,   40,
 /*   440 */   217,   46,  161,  287,   27,  140,   62,  222,  221,  172,
 /*   450 */   139,   46,   40,  215,  241,   24,   34,  239,  138,   38,
 /*   460 */   249,  250,  254,  255,  252,  248,  256,  253,  152,  272,
 /*   470 */   211,   52,   72,   72,  157,   27,   77,  102,   13,  129,
 /*   480 */   149,  146,  271,  257,   89,  170,  214,  207,  226,    9,
 /*   490 */    72,  112,  222,  222,   62,  203,  231,   94,  258,   46,
 /*   500 */   272,  139,   52,  169,   72,  157,  103,   78,  157,  183,
 /*   510 */   222,  227,  146,  271,  139,   89,   71,  214,  207,  157,
 /*   520 */    92,  272,  174,   52,  222,   72,  164,  126,   76,  258,
 /*   530 */    88,  228,  209,  146,  271,   64,   89,  107,  214,  207,
 /*   540 */   272,  273,   52,  202,   72,  222,  269,   82,  226,   55,
 /*   550 */   258,   95,  146,  271,  228,   89,  101,  214,  207,  272,
 /*   560 */    39,   52,   26,   72,  222,  269,   83,  226,  125,  258,
 /*   570 */   194,  146,  271,  209,   89,   90,  214,  207,  160,  190,
 /*   580 */    54,  176,  272,  222,   50,  228,   72,  124,  258,   75,
 /*   590 */    70,  155,  209,  199,  146,  271,  269,   89,  121,  214,
 /*   600 */   207,   65,   38,  272,   68,   52,  222,   72,   59,  228,
 /*   610 */    80,  258,   22,  188,  156,  146,  271,  154,   89,  159,
 /*   620 */   214,  207,  272,  240,   52,  243,   72,  222,   37,   84,
 /*   630 */   288,  109,  258,  105,  146,  271,  216,   89,   33,  214,
 /*   640 */   207,  272,  238,   52,  232,   72,  222,   61,   79,   17,
 /*   650 */   191,  258,  199,  146,  271,  225,   89,   44,  214,  207,
 /*   660 */    73,  157,  269,  269,  272,  222,   52,  269,   72,  269,
 /*   670 */   258,   81,  269,  269,  269,  269,  146,  271,  269,   89,
 /*   680 */   269,  214,  207,  269,  269,  272,  269,   99,  222,   72,
 /*   690 */   269,  269,  269,  258,  269,  269,  269,  212,  271,  269,
 /*   700 */    89,  269,  214,  207,  269,  269,  269,  269,  269,  222,
 /*   710 */   272,  269,   99,  269,   72,  269,  269,  143,  285,  269,
 /*   720 */   269,  269,  212,  271,  269,   89,  269,  214,  207,  272,
 /*   730 */   269,   98,  269,   72,  222,  269,  269,  269,  269,  269,
 /*   740 */   269,  212,  271,  279,   89,  269,  214,  207,  269,  269,
 /*   750 */   173,  269,  272,  222,   98,  269,   72,  269,  269,  269,
 /*   760 */   269,  269,  269,  269,  212,  271,  269,   89,  269,  214,
 /*   770 */   207,  269,  269,  150,  269,  272,  222,   98,  269,   72,
 /*   780 */   269,  269,  269,  269,  269,  269,  269,  212,  271,  269,
 /*   790 */    89,  269,  214,  207,  269,  269,  286,  269,  272,  222,
 /*   800 */    98,  269,   72,  269,  269,  269,  269,  269,  269,  269,
 /*   810 */   212,  271,  269,   89,  269,  214,  207,  269,  269,  163,
 /*   820 */   269,  272,  222,  115,  269,   72,  269,  269,  269,  269,
 /*   830 */   269,  269,  269,  212,  271,  269,   89,  269,  214,  207,
 /*   840 */   272,  269,   47,  269,   63,  222,  269,  269,  269,  269,
 /*   850 */   269,  269,  212,  271,  269,   89,  269,  214,  207,  269,
 /*   860 */   269,  269,  269,  272,  222,   49,  269,   72,  269,  269,
 /*   870 */   269,  269,  269,  269,  269,  212,  271,  269,   89,  269,
 /*   880 */   214,  207,  269,  269,  269,  269,  272,  222,  111,  269,
 /*   890 */    72,  269,  269,  269,  269,  269,  269,  269,  212,  271,
 /*   900 */   269,   89,  269,  214,  207,  269,  269,  269,  269,  272,
 /*   910 */   222,  104,  269,   72,  269,  269,  269,  269,  269,  269,
 /*   920 */   269,  212,  271,  269,   89,  269,  214,  207,  272,  269,
 /*   930 */   113,  269,   72,  222,  269,  269,  269,  269,  269,  269,
 /*   940 */   212,  271,  269,   89,  269,  214,  207,  269,  269,  269,
 /*   950 */   269,  272,  222,  117,  269,   72,  269,  269,  269,  269,
 /*   960 */   269,  269,  269,  212,  271,  269,   89,  269,  214,  207,
 /*   970 */   269,  269,  269,  269,  272,  222,  127,  269,   72,  269,
 /*   980 */   269,  269,  269,  269,  269,  269,  212,  271,  269,   89,
 /*   990 */   269,  214,  207,  269,  269,  269,  269,  272,  222,  116,
 /*  1000 */   269,   72,  269,  269,  269,  269,  269,  269,  269,  212,
 /*  1010 */   271,  269,   89,  269,  214,  207,  272,  269,   45,  269,
 /*  1020 */    63,  222,  269,  269,  269,  269,  269,  269,  212,  271,
 /*  1030 */   269,   89,  269,  214,  207,  269,  269,  269,  269,  272,
 /*  1040 */   222,   97,  269,   72,  269,  269,  269,  269,  269,  269,
 /*  1050 */   269,  212,  271,  269,   89,  269,  214,  207,  269,  269,
 /*  1060 */   269,  269,  272,  222,  122,  269,   72,  269,  269,  269,
 /*  1070 */   269,  269,  269,  269,  212,  271,  269,   89,  269,  214,
 /*  1080 */   207,  269,  269,  269,  269,  272,  222,  120,  269,   72,
 /*  1090 */   269,  269,  269,  269,  269,  272,  269,  212,  271,   72,
 /*  1100 */    89,  269,  214,  207,  269,  269,  269,  212,  271,  222,
 /*  1110 */    86,  269,  214,  207,  272,  269,  272,  269,   72,  222,
 /*  1120 */    72,  269,  269,  269,  269,  269,  212,  271,  251,   85,
 /*  1130 */   269,  214,  207,  214,  207,  269,  269,  272,  222,  269,
 /*  1140 */   222,   72,  269,  269,  269,  269,  269,  269,  269,  212,
 /*  1150 */   271,  269,   87,  269,  214,  207,  269,  269,  269,  269,
 /*  1160 */   269,  222,
    );
    static public $yy_lookahead = array(
 /*     0 */    10,   16,   17,   10,   17,   15,   16,   48,   15,   16,
 /*    10 */    20,   21,   17,   20,   21,    1,    2,    3,    4,    5,
 /*    20 */    30,   55,   78,    9,   59,   11,   60,   13,   14,   15,
 /*    30 */    16,   16,   67,   67,   44,   91,   46,   44,   94,   46,
 /*    40 */    47,   51,   98,   53,   51,   55,   53,    1,   55,    1,
 /*    50 */    60,   61,   67,   60,   61,   68,    8,   67,   63,   44,
 /*    60 */    67,   15,   16,   68,   16,   49,   31,   32,   33,   34,
 /*    70 */    35,   36,   37,   38,   39,   40,   41,   42,   43,   63,
 /*    80 */     1,   71,   72,   73,   74,   46,   10,   48,   84,   10,
 /*    90 */    16,   15,   16,   58,   15,   16,   20,   21,   17,   20,
 /*   100 */    21,   55,   84,   64,  100,   18,   30,   61,   62,   22,
 /*   110 */    23,   24,   25,   26,   27,   28,   29,   77,  100,   79,
 /*   120 */    44,  101,   46,   44,   50,   46,   52,   51,   88,   53,
 /*   130 */    51,   55,   53,    1,   55,   84,   60,   61,   17,   60,
 /*   140 */    61,   67,   17,   67,   12,   63,   67,   65,   16,   68,
 /*   150 */    63,  100,   31,   32,   33,   34,   35,   36,   37,   38,
 /*   160 */    39,   40,   41,   42,   43,   45,   31,   32,   33,   34,
 /*   170 */    35,   36,   37,   38,   39,   40,   41,   42,   43,   10,
 /*   180 */    45,   17,   17,   63,   15,   16,   16,   17,   63,   20,
 /*   190 */    21,   31,   32,   33,   34,   35,   36,   37,   38,   39,
 /*   200 */    40,   41,   42,   43,   97,   46,   10,  100,   44,   16,
 /*   210 */    97,   15,   16,   44,   50,   46,   20,   21,   53,   54,
 /*   220 */    51,   57,   53,   64,   55,    1,   17,   80,   10,   60,
 /*   230 */    61,   66,   68,   15,   16,    1,   67,   67,   20,   21,
 /*   240 */    44,   74,   46,   50,   10,   78,   80,   51,   97,   53,
 /*   250 */    16,   55,   59,   86,   87,   16,   60,   61,   91,   92,
 /*   260 */    67,   47,   44,   67,   46,   98,    1,   53,   54,   51,
 /*   270 */     5,   53,   74,   55,   79,   44,   78,   68,   60,   61,
 /*   280 */    66,   16,   10,   48,   86,   67,   74,   15,   16,   91,
 /*   290 */    92,   67,   20,   21,   58,   74,   98,   96,   59,   78,
 /*   300 */    99,   65,  101,   68,   10,   93,   67,   86,   47,   15,
 /*   310 */    16,   79,   91,   92,   20,   21,   44,   74,   46,   98,
 /*   320 */   108,   78,   63,   51,   44,   53,   65,   55,   48,   86,
 /*   330 */    60,   16,   60,   61,   91,   92,  104,   57,   44,   67,
 /*   340 */    46,   98,    1,   63,   62,   51,   17,   53,   68,   55,
 /*   350 */    60,    1,   73,   74,   60,   61,   15,   16,   53,   54,
 /*   360 */    74,   67,   76,   44,   78,   50,   47,   81,   82,   83,
 /*   370 */    77,   66,   86,   87,   44,   89,   57,   91,   92,   49,
 /*   380 */    10,   88,   67,   64,   98,   15,   16,   57,   10,  103,
 /*   390 */    20,   21,   63,   15,   16,  102,   55,   16,   20,   21,
 /*   400 */    67,   10,   61,   62,   17,   55,   15,   16,   56,   19,
 /*   410 */    60,   20,   21,   77,   44,   79,   46,   67,   67,    1,
 /*   420 */    68,   51,   44,   17,   88,   55,   62,   78,   10,   51,
 /*   430 */    60,   61,   51,   55,   16,   44,   55,   67,   60,   61,
 /*   440 */    91,   60,   51,   45,   16,   67,   55,   98,   67,   56,
 /*   450 */    63,   60,   61,   67,   17,   16,   18,   17,   67,   69,
 /*   460 */    22,   23,   24,   25,   26,   27,   28,   29,   55,   74,
 /*   470 */    51,   76,   78,   78,   68,   16,   81,   77,   44,   79,
 /*   480 */    67,   86,   87,   45,   89,   91,   91,   92,   88,  105,
 /*   490 */    78,   57,   98,   98,   55,   67,    1,   75,  103,   60,
 /*   500 */    74,   63,   76,   91,   78,   68,   67,   81,   68,   74,
 /*   510 */    98,   16,   86,   87,   63,   89,   67,   91,   92,   68,
 /*   520 */    75,   74,   19,   76,   98,   78,   67,   96,   81,  103,
 /*   530 */    84,  109,  101,   86,   87,   55,   89,   77,   91,   92,
 /*   540 */    74,   67,   76,  108,   78,   98,  100,   81,   88,   84,
 /*   550 */   103,   75,   86,   87,  109,   89,   77,   91,   92,   74,
 /*   560 */    48,   76,   50,   78,   98,  100,   81,   88,   96,  103,
 /*   570 */    45,   86,   87,  101,   89,   75,   91,   92,   85,   47,
 /*   580 */    84,   64,   74,   98,   76,  109,   78,   96,  103,   81,
 /*   590 */    45,   67,  101,  100,   86,   87,  100,   89,   67,   91,
 /*   600 */    92,   55,   69,   74,   55,   76,   98,   78,   67,  109,
 /*   610 */    81,  103,   50,   17,   67,   86,   87,   67,   89,   55,
 /*   620 */    91,   92,   74,   17,   76,    5,   78,   98,   90,   81,
 /*   630 */    17,   97,  103,   97,   86,   87,   99,   89,   56,   91,
 /*   640 */    92,   74,   88,   76,  109,   78,   98,   55,   81,   44,
 /*   650 */    82,  103,  100,   86,   87,  102,   89,   97,   91,   92,
 /*   660 */    94,   68,  110,  110,   74,   98,   76,  110,   78,  110,
 /*   670 */   103,   81,  110,  110,  110,  110,   86,   87,  110,   89,
 /*   680 */   110,   91,   92,  110,  110,   74,  110,   76,   98,   78,
 /*   690 */   110,  110,  110,  103,  110,  110,  110,   86,   87,  110,
 /*   700 */    89,  110,   91,   92,  110,  110,  110,  110,  110,   98,
 /*   710 */    74,  110,   76,  110,   78,  110,  110,  106,  107,  110,
 /*   720 */   110,  110,   86,   87,  110,   89,  110,   91,   92,   74,
 /*   730 */   110,   76,  110,   78,   98,  110,  110,  110,  110,  110,
 /*   740 */   110,   86,   87,  107,   89,  110,   91,   92,  110,  110,
 /*   750 */    95,  110,   74,   98,   76,  110,   78,  110,  110,  110,
 /*   760 */   110,  110,  110,  110,   86,   87,  110,   89,  110,   91,
 /*   770 */    92,  110,  110,   95,  110,   74,   98,   76,  110,   78,
 /*   780 */   110,  110,  110,  110,  110,  110,  110,   86,   87,  110,
 /*   790 */    89,  110,   91,   92,  110,  110,   95,  110,   74,   98,
 /*   800 */    76,  110,   78,  110,  110,  110,  110,  110,  110,  110,
 /*   810 */    86,   87,  110,   89,  110,   91,   92,  110,  110,   95,
 /*   820 */   110,   74,   98,   76,  110,   78,  110,  110,  110,  110,
 /*   830 */   110,  110,  110,   86,   87,  110,   89,  110,   91,   92,
 /*   840 */    74,  110,   76,  110,   78,   98,  110,  110,  110,  110,
 /*   850 */   110,  110,   86,   87,  110,   89,  110,   91,   92,  110,
 /*   860 */   110,  110,  110,   74,   98,   76,  110,   78,  110,  110,
 /*   870 */   110,  110,  110,  110,  110,   86,   87,  110,   89,  110,
 /*   880 */    91,   92,  110,  110,  110,  110,   74,   98,   76,  110,
 /*   890 */    78,  110,  110,  110,  110,  110,  110,  110,   86,   87,
 /*   900 */   110,   89,  110,   91,   92,  110,  110,  110,  110,   74,
 /*   910 */    98,   76,  110,   78,  110,  110,  110,  110,  110,  110,
 /*   920 */   110,   86,   87,  110,   89,  110,   91,   92,   74,  110,
 /*   930 */    76,  110,   78,   98,  110,  110,  110,  110,  110,  110,
 /*   940 */    86,   87,  110,   89,  110,   91,   92,  110,  110,  110,
 /*   950 */   110,   74,   98,   76,  110,   78,  110,  110,  110,  110,
 /*   960 */   110,  110,  110,   86,   87,  110,   89,  110,   91,   92,
 /*   970 */   110,  110,  110,  110,   74,   98,   76,  110,   78,  110,
 /*   980 */   110,  110,  110,  110,  110,  110,   86,   87,  110,   89,
 /*   990 */   110,   91,   92,  110,  110,  110,  110,   74,   98,   76,
 /*  1000 */   110,   78,  110,  110,  110,  110,  110,  110,  110,   86,
 /*  1010 */    87,  110,   89,  110,   91,   92,   74,  110,   76,  110,
 /*  1020 */    78,   98,  110,  110,  110,  110,  110,  110,   86,   87,
 /*  1030 */   110,   89,  110,   91,   92,  110,  110,  110,  110,   74,
 /*  1040 */    98,   76,  110,   78,  110,  110,  110,  110,  110,  110,
 /*  1050 */   110,   86,   87,  110,   89,  110,   91,   92,  110,  110,
 /*  1060 */   110,  110,   74,   98,   76,  110,   78,  110,  110,  110,
 /*  1070 */   110,  110,  110,  110,   86,   87,  110,   89,  110,   91,
 /*  1080 */    92,  110,  110,  110,  110,   74,   98,   76,  110,   78,
 /*  1090 */   110,  110,  110,  110,  110,   74,  110,   86,   87,   78,
 /*  1100 */    89,  110,   91,   92,  110,  110,  110,   86,   87,   98,
 /*  1110 */    89,  110,   91,   92,   74,  110,   74,  110,   78,   98,
 /*  1120 */    78,  110,  110,  110,  110,  110,   86,   87,   86,   89,
 /*  1130 */   110,   91,   92,   91,   92,  110,  110,   74,   98,  110,
 /*  1140 */    98,   78,  110,  110,  110,  110,  110,  110,  110,   86,
 /*  1150 */    87,  110,   89,  110,   91,   92,  110,  110,  110,  110,
 /*  1160 */   110,   98,
);
    const YY_SHIFT_USE_DFLT = -42;
    const YY_SHIFT_MAX = 177;
    static public $yy_shift_ofst = array(
 /*     0 */    14,   76,  -10,  -10,  -10,  -10,  -10,  -10,  -10,  -10,
 /*    10 */   -10,  -10,  294,  169,  169,  294,  169,  169,   79,  169,
 /*    20 */   169,  169,  169,  169,  169,  272,  169,  169,  169,  169,
 /*    30 */   169,   -7,  196,  218,  370,  378,  378,  378,  391,  439,
 /*    40 */   341,  280,  381,  350,   39,   -5,  -34,  451,  352,  451,
 /*    50 */   438,   14,   87,   46,  193,   74,  418,  239,  459,  235,
 /*    60 */   495,  428,  428,  512,  428,  428,  459,  495,  428,  495,
 /*    70 */   -41,  593,  -41,  -41,  121,  135,   35,  160,  160,  160,
 /*    80 */   160,  160,  160,  160,  160,  165,  214,  305,  315,  305,
 /*    90 */   234,  -15,  265,  170,   48,  132,  -13,  125,   82,   16,
 /*   100 */   406,  209,   81,   15,  387,  159,  159,  440,  437,  159,
 /*   110 */   159,  329,  413,  120,  159,  259,  259,  259,  582,  592,
 /*   120 */   259,  605,  259,  -41,  -41,  -41,  -41,  259,  -42,  -42,
 /*   130 */   -42,  -42,  -42,  164,  319,  330,  236,  434,  434,  -35,
 /*   140 */   434,  434,  224,  261,  390,  613,  533,  549,  546,  231,
 /*   150 */   545,  524,  531,  541,  562,  606,  620,  550,  564,  547,
 /*   160 */   596,  517,  532,  398,  393,  351,  333,  270,  282,  290,
 /*   170 */   364,  386,  474,  525,  480,  503,  419,  449,
);
    const YY_REDUCE_USE_DFLT = -57;
    const YY_REDUCE_MAX = 132;
    static public $yy_reduce_ofst = array(
 /*     0 */    10,  286,  395,  485,  466,  508,  529,  548,  447,  426,
 /*    10 */   590,  567,  611,  724,  655,  636,  701,  678,  942,  812,
 /*    20 */  1011,  923,  877,  854,  835,  766,  789,  965,  988,  900,
 /*    30 */   747, 1021, 1040, 1063,  167,  243,  198,  221, 1042,  -56,
 /*    40 */   212,  336,  349,  394,  201,   40,  412,   40,  293,  400,
 /*    50 */   232,  279,  232,  435,  107,  493,  500,  107,  496,  460,
 /*    60 */   445,  446,    4,  431,   51,  465,    4,  422,   18,  476,
 /*    70 */   491,  479,  431,  472,  384,  384,  384,  384,  384,  384,
 /*    80 */   384,  384,  384,  384,  384,  538,  538,  538,  552,  538,
 /*    90 */   535,  552,  535,  552,  535,  535,  554,  195,  195,  195,
 /*   100 */   554,  554,  554,  536,  195,  537,  537,  554,  554,  537,
 /*   110 */   537,  195,  566,  195,  537,  195,  195,  195,  553,  568,
 /*   120 */   195,  560,  195,   20,   20,   20,   20,  195,  151,  147,
 /*   130 */   113,  166,  534,
);
    static public $yyExpectedTokens = array(
        /* 0 */ array(1, 2, 3, 4, 5, 9, 11, 13, 14, 15, 16, ),
        /* 1 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 2 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 3 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 4 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 5 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 6 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 7 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 8 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 9 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 10 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 11 */ array(10, 15, 16, 20, 21, 30, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 12 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 13 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 14 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 15 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 16 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 17 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 18 */ array(1, 10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 19 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 20 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 21 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 22 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 23 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 24 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 25 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 26 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 27 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 28 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 29 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 30 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 31 */ array(10, 15, 16, 20, 21, 44, 46, 47, 51, 53, 55, 60, 61, 67, ),
        /* 32 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 33 */ array(10, 15, 16, 20, 21, 44, 46, 51, 53, 55, 60, 61, 67, ),
        /* 34 */ array(10, 15, 16, 20, 21, 44, 46, 51, 55, 60, 61, 67, ),
        /* 35 */ array(10, 15, 16, 20, 21, 44, 51, 55, 60, 61, 67, ),
        /* 36 */ array(10, 15, 16, 20, 21, 44, 51, 55, 60, 61, 67, ),
        /* 37 */ array(10, 15, 16, 20, 21, 44, 51, 55, 60, 61, 67, ),
        /* 38 */ array(10, 15, 16, 20, 21, 44, 51, 55, 60, 61, 67, ),
        /* 39 */ array(16, 55, 60, 67, ),
        /* 40 */ array(1, 15, 16, 55, 61, 62, ),
        /* 41 */ array(44, 48, 57, 63, 68, ),
        /* 42 */ array(16, 51, 55, 60, 67, ),
        /* 43 */ array(1, 55, 60, 67, ),
        /* 44 */ array(46, 48, 64, ),
        /* 45 */ array(17, 63, 68, ),
        /* 46 */ array(55, 60, 67, ),
        /* 47 */ array(63, 68, ),
        /* 48 */ array(56, 68, ),
        /* 49 */ array(63, 68, ),
        /* 50 */ array(18, 22, 23, 24, 25, 26, 27, 28, 29, 45, 63, ),
        /* 51 */ array(1, 2, 3, 4, 5, 9, 11, 13, 14, 15, 16, ),
        /* 52 */ array(18, 22, 23, 24, 25, 26, 27, 28, 29, 63, ),
        /* 53 */ array(1, 15, 16, 55, 61, 62, ),
        /* 54 */ array(16, 50, 59, 67, ),
        /* 55 */ array(16, 50, 52, 67, ),
        /* 56 */ array(1, 10, 16, ),
        /* 57 */ array(16, 59, 67, ),
        /* 58 */ array(16, 67, ),
        /* 59 */ array(48, 68, ),
        /* 60 */ array(1, 16, ),
        /* 61 */ array(16, 67, ),
        /* 62 */ array(16, 67, ),
        /* 63 */ array(48, 50, ),
        /* 64 */ array(16, 67, ),
        /* 65 */ array(16, 67, ),
        /* 66 */ array(16, 67, ),
        /* 67 */ array(1, 16, ),
        /* 68 */ array(16, 67, ),
        /* 69 */ array(1, 16, ),
        /* 70 */ array(48, ),
        /* 71 */ array(68, ),
        /* 72 */ array(48, ),
        /* 73 */ array(48, ),
        /* 74 */ array(17, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, ),
        /* 75 */ array(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 45, ),
        /* 76 */ array(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 58, ),
        /* 77 */ array(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, ),
        /* 78 */ array(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, ),
        /* 79 */ array(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, ),
        /* 80 */ array(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, ),
        /* 81 */ array(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, ),
        /* 82 */ array(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, ),
        /* 83 */ array(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, ),
        /* 84 */ array(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, ),
        /* 85 */ array(17, 53, 54, 66, ),
        /* 86 */ array(47, 53, 54, 66, ),
        /* 87 */ array(53, 54, 66, ),
        /* 88 */ array(16, 50, 67, ),
        /* 89 */ array(53, 54, 66, ),
        /* 90 */ array(1, 10, 16, ),
        /* 91 */ array(16, 17, 67, ),
        /* 92 */ array(1, 5, 16, ),
        /* 93 */ array(16, 17, 67, ),
        /* 94 */ array(1, 8, 16, ),
        /* 95 */ array(1, 12, 16, ),
        /* 96 */ array(17, 68, ),
        /* 97 */ array(17, 63, ),
        /* 98 */ array(63, 65, ),
        /* 99 */ array(49, 63, ),
        /* 100 */ array(17, 68, ),
        /* 101 */ array(17, 68, ),
        /* 102 */ array(17, 68, ),
        /* 103 */ array(16, 44, ),
        /* 104 */ array(17, 63, ),
        /* 105 */ array(46, 64, ),
        /* 106 */ array(46, 64, ),
        /* 107 */ array(17, 68, ),
        /* 108 */ array(17, 68, ),
        /* 109 */ array(46, 64, ),
        /* 110 */ array(46, 64, ),
        /* 111 */ array(17, 63, ),
        /* 112 */ array(55, 67, ),
        /* 113 */ array(45, 63, ),
        /* 114 */ array(46, 64, ),
        /* 115 */ array(63, ),
        /* 116 */ array(63, ),
        /* 117 */ array(63, ),
        /* 118 */ array(56, ),
        /* 119 */ array(55, ),
        /* 120 */ array(63, ),
        /* 121 */ array(44, ),
        /* 122 */ array(63, ),
        /* 123 */ array(48, ),
        /* 124 */ array(48, ),
        /* 125 */ array(48, ),
        /* 126 */ array(48, ),
        /* 127 */ array(63, ),
        /* 128 */ array(),
        /* 129 */ array(),
        /* 130 */ array(),
        /* 131 */ array(),
        /* 132 */ array(),
        /* 133 */ array(17, 44, 50, 57, 68, ),
        /* 134 */ array(44, 47, 57, 64, ),
        /* 135 */ array(44, 49, 57, ),
        /* 136 */ array(58, 65, ),
        /* 137 */ array(44, 57, ),
        /* 138 */ array(44, 57, ),
        /* 139 */ array(59, 67, ),
        /* 140 */ array(44, 57, ),
        /* 141 */ array(44, 57, ),
        /* 142 */ array(1, 67, ),
        /* 143 */ array(47, 65, ),
        /* 144 */ array(19, 69, ),
        /* 145 */ array(17, ),
        /* 146 */ array(69, ),
        /* 147 */ array(55, ),
        /* 148 */ array(55, ),
        /* 149 */ array(44, ),
        /* 150 */ array(45, ),
        /* 151 */ array(67, ),
        /* 152 */ array(67, ),
        /* 153 */ array(67, ),
        /* 154 */ array(50, ),
        /* 155 */ array(17, ),
        /* 156 */ array(5, ),
        /* 157 */ array(67, ),
        /* 158 */ array(55, ),
        /* 159 */ array(67, ),
        /* 160 */ array(17, ),
        /* 161 */ array(64, ),
        /* 162 */ array(47, ),
        /* 163 */ array(45, ),
        /* 164 */ array(56, ),
        /* 165 */ array(67, ),
        /* 166 */ array(67, ),
        /* 167 */ array(60, ),
        /* 168 */ array(62, ),
        /* 169 */ array(60, ),
        /* 170 */ array(62, ),
        /* 171 */ array(67, ),
        /* 172 */ array(67, ),
        /* 173 */ array(45, ),
        /* 174 */ array(55, ),
        /* 175 */ array(19, ),
        /* 176 */ array(51, ),
        /* 177 */ array(67, ),
        /* 178 */ array(),
        /* 179 */ array(),
        /* 180 */ array(),
        /* 181 */ array(),
        /* 182 */ array(),
        /* 183 */ array(),
        /* 184 */ array(),
        /* 185 */ array(),
        /* 186 */ array(),
        /* 187 */ array(),
        /* 188 */ array(),
        /* 189 */ array(),
        /* 190 */ array(),
        /* 191 */ array(),
        /* 192 */ array(),
        /* 193 */ array(),
        /* 194 */ array(),
        /* 195 */ array(),
        /* 196 */ array(),
        /* 197 */ array(),
        /* 198 */ array(),
        /* 199 */ array(),
        /* 200 */ array(),
        /* 201 */ array(),
        /* 202 */ array(),
        /* 203 */ array(),
        /* 204 */ array(),
        /* 205 */ array(),
        /* 206 */ array(),
        /* 207 */ array(),
        /* 208 */ array(),
        /* 209 */ array(),
        /* 210 */ array(),
        /* 211 */ array(),
        /* 212 */ array(),
        /* 213 */ array(),
        /* 214 */ array(),
        /* 215 */ array(),
        /* 216 */ array(),
        /* 217 */ array(),
        /* 218 */ array(),
        /* 219 */ array(),
        /* 220 */ array(),
        /* 221 */ array(),
        /* 222 */ array(),
        /* 223 */ array(),
        /* 224 */ array(),
        /* 225 */ array(),
        /* 226 */ array(),
        /* 227 */ array(),
        /* 228 */ array(),
        /* 229 */ array(),
        /* 230 */ array(),
        /* 231 */ array(),
        /* 232 */ array(),
        /* 233 */ array(),
        /* 234 */ array(),
        /* 235 */ array(),
        /* 236 */ array(),
        /* 237 */ array(),
        /* 238 */ array(),
        /* 239 */ array(),
        /* 240 */ array(),
        /* 241 */ array(),
        /* 242 */ array(),
        /* 243 */ array(),
        /* 244 */ array(),
        /* 245 */ array(),
        /* 246 */ array(),
        /* 247 */ array(),
        /* 248 */ array(),
        /* 249 */ array(),
        /* 250 */ array(),
        /* 251 */ array(),
        /* 252 */ array(),
        /* 253 */ array(),
        /* 254 */ array(),
        /* 255 */ array(),
        /* 256 */ array(),
        /* 257 */ array(),
        /* 258 */ array(),
        /* 259 */ array(),
        /* 260 */ array(),
        /* 261 */ array(),
        /* 262 */ array(),
        /* 263 */ array(),
        /* 264 */ array(),
        /* 265 */ array(),
        /* 266 */ array(),
        /* 267 */ array(),
        /* 268 */ array(),
        /* 269 */ array(),
        /* 270 */ array(),
        /* 271 */ array(),
        /* 272 */ array(),
        /* 273 */ array(),
        /* 274 */ array(),
        /* 275 */ array(),
        /* 276 */ array(),
        /* 277 */ array(),
        /* 278 */ array(),
        /* 279 */ array(),
        /* 280 */ array(),
        /* 281 */ array(),
        /* 282 */ array(),
        /* 283 */ array(),
        /* 284 */ array(),
        /* 285 */ array(),
        /* 286 */ array(),
        /* 287 */ array(),
        /* 288 */ array(),
);
    static public $yy_default = array(
 /*     0 */   446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
 /*    10 */   446,  446,  427,  386,  386,  446,  386,  386,  446,  446,
 /*    20 */   446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
 /*    30 */   446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
 /*    40 */   446,  318,  446,  446,  351,  446,  446,  318,  318,  318,
 /*    50 */   396,  289,  396,  446,  361,  446,  446,  361,  446,  318,
 /*    60 */   446,  446,  446,  354,  446,  446,  446,  446,  446,  446,
 /*    70 */   347,  318,  354,  346,  446,  446,  446,  410,  400,  405,
 /*    80 */   402,  409,  394,  401,  406,  446,  446,  391,  446,  325,
 /*    90 */   446,  446,  446,  446,  446,  446,  446,  446,  385,  430,
 /*   100 */   446,  446,  446,  361,  446,  377,  378,  446,  446,  379,
 /*   110 */   359,  446,  446,  446,  380,  428,  397,  319,  327,  446,
 /*   120 */   323,  361,  429,  352,  349,  348,  374,  310,  361,  390,
 /*   130 */   361,  390,  361,  324,  446,  324,  446,  324,  411,  446,
 /*   140 */   446,  392,  446,  446,  328,  321,  328,  446,  446,  350,
 /*   150 */   446,  446,  446,  446,  320,  446,  446,  446,  446,  446,
 /*   160 */   446,  336,  446,  446,  372,  446,  446,  446,  446,  446,
 /*   170 */   446,  446,  446,  446,  446,  332,  446,  446,  438,  432,
 /*   180 */   433,  345,  440,  437,  365,  290,  441,  434,  309,  366,
 /*   190 */   367,  322,  369,  313,  383,  435,  439,  344,  368,  371,
 /*   200 */   381,  312,  431,  372,  311,  305,  339,  340,  376,  375,
 /*   210 */   338,  337,  328,  329,  335,  355,  360,  364,  330,  342,
 /*   220 */   363,  362,  356,  357,  358,  389,  317,  445,  443,  294,
 /*   230 */   295,  444,  442,  291,  292,  293,  296,  297,  316,  314,
 /*   240 */   315,  302,  301,  298,  299,  300,  343,  387,  418,  419,
 /*   250 */   420,  412,  417,  416,  413,  414,  415,  341,  393,  422,
 /*   260 */   423,  395,  421,  408,  403,  404,  407,  399,  398,  370,
 /*   270 */   373,  332,  353,  326,  331,  388,  436,  303,  424,  426,
 /*   280 */   304,  306,  307,  334,  333,  425,  384,  382,  308,
);
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    self::YYNOCODE      is a number which corresponds
**                        to no legal terminal or nonterminal number.  This
**                        number is used to fill in empty slots of the hash 
**                        table.
**    self::YYFALLBACK    If defined, this indicates that one or more tokens
**                        have fall-back values which should be used if the
**                        original value of the token will not parse.
**    self::YYSTACKDEPTH  is the maximum depth of the parser's stack.
**    self::YYNSTATE      the combined number of states.
**    self::YYNRULE       the number of rules in the grammar
**    self::YYERRORSYMBOL is the code number of the error symbol.  If not
**                        defined, then do no error processing.
*/
    const YYNOCODE = 111;
    const YYSTACKDEPTH = 100;
    const YYNSTATE = 289;
    const YYNRULE = 157;
    const YYERRORSYMBOL = 70;
    const YYERRSYMDT = 'yy0';
    const YYFALLBACK = 1;
    /** The next table maps tokens into fallback tokens.  If a construct
     * like the following:
     * 
     *      %fallback ID X Y Z.
     *
     * appears in the grammer, then ID becomes a fallback token for X, Y,
     * and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
     * but it does not parse, the type of the token is changed to ID and
     * the parse is retried before an error is thrown.
     */
    static public $yyFallback = array(
    0,  /*          $ => nothing */
    0,  /*      OTHER => nothing */
    1,  /*        XML => OTHER */
    1,  /*        PHP => OTHER */
    1,  /* SHORTTAGSTART => OTHER */
    1,  /* SHORTTAGEND => OTHER */
    1,  /*   PHPSTART => OTHER */
    1,  /*     PHPEND => OTHER */
    1,  /* COMMENTEND => OTHER */
    1,  /* COMMENTSTART => OTHER */
    1,  /* SINGLEQUOTE => OTHER */
    1,  /* LITERALSTART => OTHER */
    1,  /* LITERALEND => OTHER */
    1,  /*  LDELIMTAG => OTHER */
    1,  /*  RDELIMTAG => OTHER */
    1,  /*  LDELSLASH => OTHER */
    1,  /*       LDEL => OTHER */
    1,  /*       RDEL => OTHER */
    1,  /*       ISIN => OTHER */
    1,  /*         AS => OTHER */
    1,  /*    BOOLEAN => OTHER */
    1,  /*       NULL => OTHER */
    1,  /*   IDENTITY => OTHER */
    1,  /* NONEIDENTITY => OTHER */
    1,  /*     EQUALS => OTHER */
    1,  /*  NOTEQUALS => OTHER */
    1,  /* GREATEREQUAL => OTHER */
    1,  /*  LESSEQUAL => OTHER */
    1,  /* GREATERTHAN => OTHER */
    1,  /*   LESSTHAN => OTHER */
    1,  /*        NOT => OTHER */
    1,  /*       LAND => OTHER */
    1,  /*        LOR => OTHER */
    1,  /*       LXOR => OTHER */
    1,  /*    ISODDBY => OTHER */
    1,  /* ISNOTODDBY => OTHER */
    1,  /*      ISODD => OTHER */
    1,  /*   ISNOTODD => OTHER */
    1,  /*   ISEVENBY => OTHER */
    1,  /* ISNOTEVENBY => OTHER */
    1,  /*     ISEVEN => OTHER */
    1,  /*  ISNOTEVEN => OTHER */
    1,  /*    ISDIVBY => OTHER */
    1,  /* ISNOTDIVBY => OTHER */
    1,  /*      OPENP => OTHER */
    1,  /*     CLOSEP => OTHER */
    1,  /*      OPENB => OTHER */
    1,  /*     CLOSEB => OTHER */
    1,  /*        PTR => OTHER */
    1,  /*       APTR => OTHER */
    1,  /*      EQUAL => OTHER */
    1,  /*    INTEGER => OTHER */
    1,  /*     INCDEC => OTHER */
    1,  /*    UNIMATH => OTHER */
    1,  /*       MATH => OTHER */
    1,  /*     DOLLAR => OTHER */
    1,  /*      COLON => OTHER */
    1,  /* DOUBLECOLON => OTHER */
    1,  /*  SEMICOLON => OTHER */
    1,  /*         AT => OTHER */
    1,  /*      HATCH => OTHER */
    1,  /*      QUOTE => OTHER */
    1,  /*   BACKTICK => OTHER */
    1,  /*       VERT => OTHER */
    1,  /*        DOT => OTHER */
    1,  /*      COMMA => OTHER */
    1,  /*     ANDSYM => OTHER */
    1,  /*         ID => OTHER */
    1,  /*      SPACE => OTHER */
    1,  /* INSTANCEOF => OTHER */
    );
    /**
     * Turn parser tracing on by giving a stream to which to write the trace
     * and a prompt to preface each trace message.  Tracing is turned off
     * by making either argument NULL 
     *
     * Inputs:
     * 
     * - A stream resource to which trace output should be written.
     *   If NULL, then tracing is turned off.
     * - A prefix string written at the beginning of every
     *   line of trace output.  If NULL, then tracing is
     *   turned off.
     *
     * Outputs:
     * 
     * - None.
     * @param resource
     * @param string
     */
    static function Trace($TraceFILE, $zTracePrompt)
    {
        if (!$TraceFILE) {
            $zTracePrompt = 0;
        } elseif (!$zTracePrompt) {
            $TraceFILE = 0;
        }
        self::$yyTraceFILE = $TraceFILE;
        self::$yyTracePrompt = $zTracePrompt;
    }

    /**
     * Output debug information to output (php://output stream)
     */
    static function PrintTrace()
    {
        self::$yyTraceFILE = fopen('php://output', 'w');
        self::$yyTracePrompt = '<br>';
    }

    /**
     * @var resource|0
     */
    static public $yyTraceFILE;
    /**
     * String to prepend to debug output
     * @var string|0
     */
    static public $yyTracePrompt;
    /**
     * @var int
     */
    public $yyidx;                    /* Index of top element in stack */
    /**
     * @var int
     */
    public $yyerrcnt;                 /* Shifts left before out of the error */
    /**
     * @var array
     */
    public $yystack = array();  /* The parser's stack */

    /**
     * For tracing shifts, the names of all terminals and nonterminals
     * are required.  The following table supplies these names
     * @var array
     */
    public $yyTokenName = array( 
  '$',             'OTHER',         'XML',           'PHP',         
  'SHORTTAGSTART',  'SHORTTAGEND',   'PHPSTART',      'PHPEND',      
  'COMMENTEND',    'COMMENTSTART',  'SINGLEQUOTE',   'LITERALSTART',
  'LITERALEND',    'LDELIMTAG',     'RDELIMTAG',     'LDELSLASH',   
  'LDEL',          'RDEL',          'ISIN',          'AS',          
  'BOOLEAN',       'NULL',          'IDENTITY',      'NONEIDENTITY',
  'EQUALS',        'NOTEQUALS',     'GREATEREQUAL',  'LESSEQUAL',   
  'GREATERTHAN',   'LESSTHAN',      'NOT',           'LAND',        
  'LOR',           'LXOR',          'ISODDBY',       'ISNOTODDBY',  
  'ISODD',         'ISNOTODD',      'ISEVENBY',      'ISNOTEVENBY', 
  'ISEVEN',        'ISNOTEVEN',     'ISDIVBY',       'ISNOTDIVBY',  
  'OPENP',         'CLOSEP',        'OPENB',         'CLOSEB',      
  'PTR',           'APTR',          'EQUAL',         'INTEGER',     
  'INCDEC',        'UNIMATH',       'MATH',          'DOLLAR',      
  'COLON',         'DOUBLECOLON',   'SEMICOLON',     'AT',          
  'HATCH',         'QUOTE',         'BACKTICK',      'VERT',        
  'DOT',           'COMMA',         'ANDSYM',        'ID',          
  'SPACE',         'INSTANCEOF',    'error',         'start',       
  'template',      'template_element',  'smartytag',     'text',        
  'expr',          'attributes',    'varindexed',    'modifier',    
  'modparameters',  'ifexprs',       'statement',     'statements',  
  'varvar',        'foraction',     'value',         'array',       
  'attribute',     'exprs',         'math',          'variable',    
  'function',      'doublequoted',  'method',        'params',      
  'objectchain',   'arrayindex',    'object',        'indexdef',    
  'varvarele',     'objectelement',  'modparameter',  'ifexpr',      
  'ifcond',        'lop',           'arrayelements',  'arrayelement',
  'doublequotedcontent',  'textelement', 
    );

    /**
     * For tracing reduce actions, the names of all rules are required.
     * @var array
     */
    static public $yyRuleName = array(
 /*   0 */ "start ::= template",
 /*   1 */ "template ::= template_element",
 /*   2 */ "template ::= template template_element",
 /*   3 */ "template_element ::= smartytag",
 /*   4 */ "template_element ::= COMMENTSTART text COMMENTEND",
 /*   5 */ "template_element ::= LITERALSTART text LITERALEND",
 /*   6 */ "template_element ::= LDELIMTAG",
 /*   7 */ "template_element ::= RDELIMTAG",
 /*   8 */ "template_element ::= PHP text SHORTTAGEND",
 /*   9 */ "template_element ::= SHORTTAGSTART DOLLAR ID SHORTTAGEND",
 /*  10 */ "template_element ::= XML",
 /*  11 */ "template_element ::= SHORTTAGEND",
 /*  12 */ "template_element ::= OTHER",
 /*  13 */ "smartytag ::= LDEL expr attributes RDEL",
 /*  14 */ "smartytag ::= LDEL varindexed EQUAL expr attributes RDEL",
 /*  15 */ "smartytag ::= LDEL ID attributes RDEL",
 /*  16 */ "smartytag ::= LDEL ID PTR ID attributes RDEL",
 /*  17 */ "smartytag ::= LDEL ID modifier modparameters attributes RDEL",
 /*  18 */ "smartytag ::= LDEL ID SPACE ifexprs RDEL",
 /*  19 */ "smartytag ::= LDEL ID SPACE statement RDEL",
 /*  20 */ "smartytag ::= LDEL ID SPACE statements SEMICOLON ifexprs SEMICOLON DOLLAR varvar foraction RDEL",
 /*  21 */ "foraction ::= EQUAL expr",
 /*  22 */ "foraction ::= INCDEC",
 /*  23 */ "smartytag ::= LDEL ID SPACE value AS DOLLAR varvar RDEL",
 /*  24 */ "smartytag ::= LDEL ID SPACE array AS DOLLAR varvar RDEL",
 /*  25 */ "smartytag ::= LDELSLASH ID attributes RDEL",
 /*  26 */ "smartytag ::= LDELSLASH ID PTR ID RDEL",
 /*  27 */ "attributes ::= attributes attribute",
 /*  28 */ "attributes ::= attribute",
 /*  29 */ "attributes ::=",
 /*  30 */ "attribute ::= SPACE ID EQUAL expr",
 /*  31 */ "attribute ::= SPACE ID",
 /*  32 */ "statements ::= statement",
 /*  33 */ "statements ::= statements COMMA statement",
 /*  34 */ "statement ::= DOLLAR varvar EQUAL expr",
 /*  35 */ "expr ::= ID",
 /*  36 */ "expr ::= exprs",
 /*  37 */ "expr ::= DOLLAR ID COLON ID",
 /*  38 */ "expr ::= expr modifier modparameters",
 /*  39 */ "exprs ::= value",
 /*  40 */ "exprs ::= UNIMATH value",
 /*  41 */ "exprs ::= exprs math value",
 /*  42 */ "exprs ::= exprs ANDSYM value",
 /*  43 */ "exprs ::= array",
 /*  44 */ "math ::= UNIMATH",
 /*  45 */ "math ::= MATH",
 /*  46 */ "value ::= variable",
 /*  47 */ "value ::= INTEGER",
 /*  48 */ "value ::= INTEGER DOT INTEGER",
 /*  49 */ "value ::= BOOLEAN",
 /*  50 */ "value ::= NULL",
 /*  51 */ "value ::= function",
 /*  52 */ "value ::= OPENP expr CLOSEP",
 /*  53 */ "value ::= SINGLEQUOTE text SINGLEQUOTE",
 /*  54 */ "value ::= SINGLEQUOTE SINGLEQUOTE",
 /*  55 */ "value ::= QUOTE doublequoted QUOTE",
 /*  56 */ "value ::= QUOTE QUOTE",
 /*  57 */ "value ::= ID DOUBLECOLON method",
 /*  58 */ "value ::= ID DOUBLECOLON DOLLAR ID OPENP params CLOSEP",
 /*  59 */ "value ::= ID DOUBLECOLON method objectchain",
 /*  60 */ "value ::= ID DOUBLECOLON DOLLAR ID OPENP params CLOSEP objectchain",
 /*  61 */ "value ::= ID DOUBLECOLON ID",
 /*  62 */ "value ::= ID DOUBLECOLON DOLLAR ID arrayindex",
 /*  63 */ "value ::= ID DOUBLECOLON DOLLAR ID arrayindex objectchain",
 /*  64 */ "value ::= smartytag",
 /*  65 */ "variable ::= varindexed",
 /*  66 */ "variable ::= DOLLAR varvar AT ID",
 /*  67 */ "variable ::= object",
 /*  68 */ "variable ::= HATCH ID HATCH",
 /*  69 */ "variable ::= HATCH variable HATCH",
 /*  70 */ "varindexed ::= DOLLAR varvar arrayindex",
 /*  71 */ "arrayindex ::= arrayindex indexdef",
 /*  72 */ "arrayindex ::=",
 /*  73 */ "indexdef ::= DOT ID",
 /*  74 */ "indexdef ::= DOT INTEGER",
 /*  75 */ "indexdef ::= DOT variable",
 /*  76 */ "indexdef ::= DOT LDEL exprs RDEL",
 /*  77 */ "indexdef ::= OPENB ID CLOSEB",
 /*  78 */ "indexdef ::= OPENB ID DOT ID CLOSEB",
 /*  79 */ "indexdef ::= OPENB exprs CLOSEB",
 /*  80 */ "indexdef ::= OPENB CLOSEB",
 /*  81 */ "varvar ::= varvarele",
 /*  82 */ "varvar ::= varvar varvarele",
 /*  83 */ "varvarele ::= ID",
 /*  84 */ "varvarele ::= LDEL expr RDEL",
 /*  85 */ "object ::= varindexed objectchain",
 /*  86 */ "objectchain ::= objectelement",
 /*  87 */ "objectchain ::= objectchain objectelement",
 /*  88 */ "objectelement ::= PTR ID arrayindex",
 /*  89 */ "objectelement ::= PTR variable arrayindex",
 /*  90 */ "objectelement ::= PTR LDEL expr RDEL arrayindex",
 /*  91 */ "objectelement ::= PTR ID LDEL expr RDEL arrayindex",
 /*  92 */ "objectelement ::= PTR method",
 /*  93 */ "function ::= ID OPENP params CLOSEP",
 /*  94 */ "method ::= ID OPENP params CLOSEP",
 /*  95 */ "params ::= expr COMMA params",
 /*  96 */ "params ::= expr",
 /*  97 */ "params ::=",
 /*  98 */ "modifier ::= VERT AT ID",
 /*  99 */ "modifier ::= VERT ID",
 /* 100 */ "modparameters ::= modparameters modparameter",
 /* 101 */ "modparameters ::=",
 /* 102 */ "modparameter ::= COLON exprs",
 /* 103 */ "modparameter ::= COLON ID",
 /* 104 */ "ifexprs ::= ifexpr",
 /* 105 */ "ifexprs ::= NOT ifexprs",
 /* 106 */ "ifexprs ::= OPENP ifexprs CLOSEP",
 /* 107 */ "ifexpr ::= expr",
 /* 108 */ "ifexpr ::= expr ifcond expr",
 /* 109 */ "ifexpr ::= expr ISIN array",
 /* 110 */ "ifexpr ::= expr ISIN value",
 /* 111 */ "ifexpr ::= ifexprs lop ifexprs",
 /* 112 */ "ifexpr ::= ifexprs ISDIVBY ifexprs",
 /* 113 */ "ifexpr ::= ifexprs ISNOTDIVBY ifexprs",
 /* 114 */ "ifexpr ::= ifexprs ISEVEN",
 /* 115 */ "ifexpr ::= ifexprs ISNOTEVEN",
 /* 116 */ "ifexpr ::= ifexprs ISEVENBY ifexprs",
 /* 117 */ "ifexpr ::= ifexprs ISNOTEVENBY ifexprs",
 /* 118 */ "ifexpr ::= ifexprs ISODD",
 /* 119 */ "ifexpr ::= ifexprs ISNOTODD",
 /* 120 */ "ifexpr ::= ifexprs ISODDBY ifexprs",
 /* 121 */ "ifexpr ::= ifexprs ISNOTODDBY ifexprs",
 /* 122 */ "ifexpr ::= value INSTANCEOF ID",
 /* 123 */ "ifexpr ::= value INSTANCEOF value",
 /* 124 */ "ifcond ::= EQUALS",
 /* 125 */ "ifcond ::= NOTEQUALS",
 /* 126 */ "ifcond ::= GREATERTHAN",
 /* 127 */ "ifcond ::= LESSTHAN",
 /* 128 */ "ifcond ::= GREATEREQUAL",
 /* 129 */ "ifcond ::= LESSEQUAL",
 /* 130 */ "ifcond ::= IDENTITY",
 /* 131 */ "ifcond ::= NONEIDENTITY",
 /* 132 */ "lop ::= LAND",
 /* 133 */ "lop ::= LOR",
 /* 134 */ "lop ::= LXOR",
 /* 135 */ "array ::= OPENB arrayelements CLOSEB",
 /* 136 */ "arrayelements ::= arrayelement",
 /* 137 */ "arrayelements ::= arrayelements COMMA arrayelement",
 /* 138 */ "arrayelements ::=",
 /* 139 */ "arrayelement ::= expr APTR expr",
 /* 140 */ "arrayelement ::= ID APTR expr",
 /* 141 */ "arrayelement ::= expr",
 /* 142 */ "doublequoted ::= doublequoted doublequotedcontent",
 /* 143 */ "doublequoted ::= doublequotedcontent",
 /* 144 */ "doublequotedcontent ::= BACKTICK ID BACKTICK",
 /* 145 */ "doublequotedcontent ::= BACKTICK variable BACKTICK",
 /* 146 */ "doublequotedcontent ::= DOLLAR ID",
 /* 147 */ "doublequotedcontent ::= LDEL expr RDEL",
 /* 148 */ "doublequotedcontent ::= smartytag",
 /* 149 */ "doublequotedcontent ::= DOLLAR OTHER",
 /* 150 */ "doublequotedcontent ::= LDEL OTHER",
 /* 151 */ "doublequotedcontent ::= BACKTICK OTHER",
 /* 152 */ "doublequotedcontent ::= OTHER",
 /* 153 */ "text ::= text textelement",
 /* 154 */ "text ::= textelement",
 /* 155 */ "textelement ::= OTHER",
 /* 156 */ "textelement ::= LDEL",
    );

    /**
     * This function returns the symbolic name associated with a token
     * value.
     * @param int
     * @return string
     */
    function tokenName($tokenType)
    {
        if ($tokenType === 0) {
            return 'End of Input';
        }
        if ($tokenType > 0 && $tokenType < count($this->yyTokenName)) {
            return $this->yyTokenName[$tokenType];
        } else {
            return "Unknown";
        }
    }

    /**
     * The following function deletes the value associated with a
     * symbol.  The symbol can be either a terminal or nonterminal.
     * @param int the symbol code
     * @param mixed the symbol's value
     */
    static function yy_destructor($yymajor, $yypminor)
    {
        switch ($yymajor) {
        /* Here is inserted the actions which take place when a
        ** terminal or non-terminal is destroyed.  This can happen
        ** when the symbol is popped from the stack during a
        ** reduce or during error processing or when a parser is 
        ** being destroyed before it is finished parsing.
        **
        ** Note: during a reduce, the only symbols destroyed are those
        ** which appear on the RHS of the rule, but which are not used
        ** inside the C code.
        */
            default:  break;   /* If no destructor action specified: do nothing */
        }
    }

    /**
     * Pop the parser's stack once.
     *
     * If there is a destructor routine associated with the token which
     * is popped from the stack, then call it.
     *
     * Return the major token number for the symbol popped.
     * @param TP_yyParser
     * @return int
     */
    function yy_pop_parser_stack()
    {
        if (!count($this->yystack)) {
            return;
        }
        $yytos = array_pop($this->yystack);
        if (self::$yyTraceFILE && $this->yyidx >= 0) {
            fwrite(self::$yyTraceFILE,
                self::$yyTracePrompt . 'Popping ' . $this->yyTokenName[$yytos->major] .
                    "\n");
        }
        $yymajor = $yytos->major;
        self::yy_destructor($yymajor, $yytos->minor);
        $this->yyidx--;
        return $yymajor;
    }

    /**
     * Deallocate and destroy a parser.  Destructors are all called for
     * all stack elements before shutting the parser down.
     */
    function __destruct()
    {
        while ($this->yyidx >= 0) {
            $this->yy_pop_parser_stack();
        }
        if (is_resource(self::$yyTraceFILE)) {
            fclose(self::$yyTraceFILE);
        }
    }

    /**
     * Based on the current state and parser stack, get a list of all
     * possible lookahead tokens
     * @param int
     * @return array
     */
    function yy_get_expected_tokens($token)
    {
        $state = $this->yystack[$this->yyidx]->stateno;
        $expected = self::$yyExpectedTokens[$state];
        if (in_array($token, self::$yyExpectedTokens[$state], true)) {
            return $expected;
        }
        $stack = $this->yystack;
        $yyidx = $this->yyidx;
        do {
            $yyact = $this->yy_find_shift_action($token);
            if ($yyact >= self::YYNSTATE && $yyact < self::YYNSTATE + self::YYNRULE) {
                // reduce action
                $done = 0;
                do {
                    if ($done++ == 100) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // too much recursion prevents proper detection
                        // so give up
                        return array_unique($expected);
                    }
                    $yyruleno = $yyact - self::YYNSTATE;
                    $this->yyidx -= self::$yyRuleInfo[$yyruleno]['rhs'];
                    $nextstate = $this->yy_find_reduce_action(
                        $this->yystack[$this->yyidx]->stateno,
                        self::$yyRuleInfo[$yyruleno]['lhs']);
                    if (isset(self::$yyExpectedTokens[$nextstate])) {
                        $expected += self::$yyExpectedTokens[$nextstate];
                            if (in_array($token,
                                  self::$yyExpectedTokens[$nextstate], true)) {
                            $this->yyidx = $yyidx;
                            $this->yystack = $stack;
                            return array_unique($expected);
                        }
                    }
                    if ($nextstate < self::YYNSTATE) {
                        // we need to shift a non-terminal
                        $this->yyidx++;
                        $x = new TP_yyStackEntry;
                        $x->stateno = $nextstate;
                        $x->major = self::$yyRuleInfo[$yyruleno]['lhs'];
                        $this->yystack[$this->yyidx] = $x;
                        continue 2;
                    } elseif ($nextstate == self::YYNSTATE + self::YYNRULE + 1) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // the last token was just ignored, we can't accept
                        // by ignoring input, this is in essence ignoring a
                        // syntax error!
                        return array_unique($expected);
                    } elseif ($nextstate === self::YY_NO_ACTION) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // input accepted, but not shifted (I guess)
                        return $expected;
                    } else {
                        $yyact = $nextstate;
                    }
                } while (true);
            }
            break;
        } while (true);
        return array_unique($expected);
    }

    /**
     * Based on the parser state and current parser stack, determine whether
     * the lookahead token is possible.
     * 
     * The parser will convert the token value to an error token if not.  This
     * catches some unusual edge cases where the parser would fail.
     * @param int
     * @return bool
     */
    function yy_is_expected_token($token)
    {
        if ($token === 0) {
            return true; // 0 is not part of this
        }
        $state = $this->yystack[$this->yyidx]->stateno;
        if (in_array($token, self::$yyExpectedTokens[$state], true)) {
            return true;
        }
        $stack = $this->yystack;
        $yyidx = $this->yyidx;
        do {
            $yyact = $this->yy_find_shift_action($token);
            if ($yyact >= self::YYNSTATE && $yyact < self::YYNSTATE + self::YYNRULE) {
                // reduce action
                $done = 0;
                do {
                    if ($done++ == 100) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // too much recursion prevents proper detection
                        // so give up
                        return true;
                    }
                    $yyruleno = $yyact - self::YYNSTATE;
                    $this->yyidx -= self::$yyRuleInfo[$yyruleno]['rhs'];
                    $nextstate = $this->yy_find_reduce_action(
                        $this->yystack[$this->yyidx]->stateno,
                        self::$yyRuleInfo[$yyruleno]['lhs']);
                    if (isset(self::$yyExpectedTokens[$nextstate]) &&
                          in_array($token, self::$yyExpectedTokens[$nextstate], true)) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        return true;
                    }
                    if ($nextstate < self::YYNSTATE) {
                        // we need to shift a non-terminal
                        $this->yyidx++;
                        $x = new TP_yyStackEntry;
                        $x->stateno = $nextstate;
                        $x->major = self::$yyRuleInfo[$yyruleno]['lhs'];
                        $this->yystack[$this->yyidx] = $x;
                        continue 2;
                    } elseif ($nextstate == self::YYNSTATE + self::YYNRULE + 1) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        if (!$token) {
                            // end of input: this is valid
                            return true;
                        }
                        // the last token was just ignored, we can't accept
                        // by ignoring input, this is in essence ignoring a
                        // syntax error!
                        return false;
                    } elseif ($nextstate === self::YY_NO_ACTION) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // input accepted, but not shifted (I guess)
                        return true;
                    } else {
                        $yyact = $nextstate;
                    }
                } while (true);
            }
            break;
        } while (true);
        $this->yyidx = $yyidx;
        $this->yystack = $stack;
        return true;
    }

    /**
     * Find the appropriate action for a parser given the terminal
     * look-ahead token iLookAhead.
     *
     * If the look-ahead token is YYNOCODE, then check to see if the action is
     * independent of the look-ahead.  If it is, return the action, otherwise
     * return YY_NO_ACTION.
     * @param int The look-ahead token
     */
    function yy_find_shift_action($iLookAhead)
    {
        $stateno = $this->yystack[$this->yyidx]->stateno;
     
        /* if ($this->yyidx < 0) return self::YY_NO_ACTION;  */
        if (!isset(self::$yy_shift_ofst[$stateno])) {
            // no shift actions
            return self::$yy_default[$stateno];
        }
        $i = self::$yy_shift_ofst[$stateno];
        if ($i === self::YY_SHIFT_USE_DFLT) {
            return self::$yy_default[$stateno];
        }
        if ($iLookAhead == self::YYNOCODE) {
            return self::YY_NO_ACTION;
        }
        $i += $iLookAhead;
        if ($i < 0 || $i >= self::YY_SZ_ACTTAB ||
              self::$yy_lookahead[$i] != $iLookAhead) {
            if (count(self::$yyFallback) && $iLookAhead < count(self::$yyFallback)
                   && ($iFallback = self::$yyFallback[$iLookAhead]) != 0) {
                if (self::$yyTraceFILE) {
                    fwrite(self::$yyTraceFILE, self::$yyTracePrompt . "FALLBACK " .
                        $this->yyTokenName[$iLookAhead] . " => " .
                        $this->yyTokenName[$iFallback] . "\n");
                }
                return $this->yy_find_shift_action($iFallback);
            }
            return self::$yy_default[$stateno];
        } else {
            return self::$yy_action[$i];
        }
    }

    /**
     * Find the appropriate action for a parser given the non-terminal
     * look-ahead token $iLookAhead.
     *
     * If the look-ahead token is self::YYNOCODE, then check to see if the action is
     * independent of the look-ahead.  If it is, return the action, otherwise
     * return self::YY_NO_ACTION.
     * @param int Current state number
     * @param int The look-ahead token
     */
    function yy_find_reduce_action($stateno, $iLookAhead)
    {
        /* $stateno = $this->yystack[$this->yyidx]->stateno; */

        if (!isset(self::$yy_reduce_ofst[$stateno])) {
            return self::$yy_default[$stateno];
        }
        $i = self::$yy_reduce_ofst[$stateno];
        if ($i == self::YY_REDUCE_USE_DFLT) {
            return self::$yy_default[$stateno];
        }
        if ($iLookAhead == self::YYNOCODE) {
            return self::YY_NO_ACTION;
        }
        $i += $iLookAhead;
        if ($i < 0 || $i >= self::YY_SZ_ACTTAB ||
              self::$yy_lookahead[$i] != $iLookAhead) {
            return self::$yy_default[$stateno];
        } else {
            return self::$yy_action[$i];
        }
    }

    /**
     * Perform a shift action.
     * @param int The new state to shift in
     * @param int The major token to shift in
     * @param mixed the minor token to shift in
     */
    function yy_shift($yyNewState, $yyMajor, $yypMinor)
    {
        $this->yyidx++;
        if ($this->yyidx >= self::YYSTACKDEPTH) {
            $this->yyidx--;
            if (self::$yyTraceFILE) {
                fprintf(self::$yyTraceFILE, "%sStack Overflow!\n", self::$yyTracePrompt);
            }
            while ($this->yyidx >= 0) {
                $this->yy_pop_parser_stack();
            }
            /* Here code is inserted which will execute if the parser
            ** stack ever overflows */
            return;
        }
        $yytos = new TP_yyStackEntry;
        $yytos->stateno = $yyNewState;
        $yytos->major = $yyMajor;
        $yytos->minor = $yypMinor;
        array_push($this->yystack, $yytos);
        if (self::$yyTraceFILE && $this->yyidx > 0) {
            fprintf(self::$yyTraceFILE, "%sShift %d\n", self::$yyTracePrompt,
                $yyNewState);
            fprintf(self::$yyTraceFILE, "%sStack:", self::$yyTracePrompt);
            for($i = 1; $i <= $this->yyidx; $i++) {
                fprintf(self::$yyTraceFILE, " %s",
                    $this->yyTokenName[$this->yystack[$i]->major]);
            }
            fwrite(self::$yyTraceFILE,"\n");
        }
    }

    /**
     * The following table contains information about every rule that
     * is used during the reduce.
     *
     * <pre>
     * array(
     *  array(
     *   int $lhs;         Symbol on the left-hand side of the rule
     *   int $nrhs;     Number of right-hand side symbols in the rule
     *  ),...
     * );
     * </pre>
     */
    static public $yyRuleInfo = array(
  array( 'lhs' => 71, 'rhs' => 1 ),
  array( 'lhs' => 72, 'rhs' => 1 ),
  array( 'lhs' => 72, 'rhs' => 2 ),
  array( 'lhs' => 73, 'rhs' => 1 ),
  array( 'lhs' => 73, 'rhs' => 3 ),
  array( 'lhs' => 73, 'rhs' => 3 ),
  array( 'lhs' => 73, 'rhs' => 1 ),
  array( 'lhs' => 73, 'rhs' => 1 ),
  array( 'lhs' => 73, 'rhs' => 3 ),
  array( 'lhs' => 73, 'rhs' => 4 ),
  array( 'lhs' => 73, 'rhs' => 1 ),
  array( 'lhs' => 73, 'rhs' => 1 ),
  array( 'lhs' => 73, 'rhs' => 1 ),
  array( 'lhs' => 74, 'rhs' => 4 ),
  array( 'lhs' => 74, 'rhs' => 6 ),
  array( 'lhs' => 74, 'rhs' => 4 ),
  array( 'lhs' => 74, 'rhs' => 6 ),
  array( 'lhs' => 74, 'rhs' => 6 ),
  array( 'lhs' => 74, 'rhs' => 5 ),
  array( 'lhs' => 74, 'rhs' => 5 ),
  array( 'lhs' => 74, 'rhs' => 11 ),
  array( 'lhs' => 85, 'rhs' => 2 ),
  array( 'lhs' => 85, 'rhs' => 1 ),
  array( 'lhs' => 74, 'rhs' => 8 ),
  array( 'lhs' => 74, 'rhs' => 8 ),
  array( 'lhs' => 74, 'rhs' => 4 ),
  array( 'lhs' => 74, 'rhs' => 5 ),
  array( 'lhs' => 77, 'rhs' => 2 ),
  array( 'lhs' => 77, 'rhs' => 1 ),
  array( 'lhs' => 77, 'rhs' => 0 ),
  array( 'lhs' => 88, 'rhs' => 4 ),
  array( 'lhs' => 88, 'rhs' => 2 ),
  array( 'lhs' => 83, 'rhs' => 1 ),
  array( 'lhs' => 83, 'rhs' => 3 ),
  array( 'lhs' => 82, 'rhs' => 4 ),
  array( 'lhs' => 76, 'rhs' => 1 ),
  array( 'lhs' => 76, 'rhs' => 1 ),
  array( 'lhs' => 76, 'rhs' => 4 ),
  array( 'lhs' => 76, 'rhs' => 3 ),
  array( 'lhs' => 89, 'rhs' => 1 ),
  array( 'lhs' => 89, 'rhs' => 2 ),
  array( 'lhs' => 89, 'rhs' => 3 ),
  array( 'lhs' => 89, 'rhs' => 3 ),
  array( 'lhs' => 89, 'rhs' => 1 ),
  array( 'lhs' => 90, 'rhs' => 1 ),
  array( 'lhs' => 90, 'rhs' => 1 ),
  array( 'lhs' => 86, 'rhs' => 1 ),
  array( 'lhs' => 86, 'rhs' => 1 ),
  array( 'lhs' => 86, 'rhs' => 3 ),
  array( 'lhs' => 86, 'rhs' => 1 ),
  array( 'lhs' => 86, 'rhs' => 1 ),
  array( 'lhs' => 86, 'rhs' => 1 ),
  array( 'lhs' => 86, 'rhs' => 3 ),
  array( 'lhs' => 86, 'rhs' => 3 ),
  array( 'lhs' => 86, 'rhs' => 2 ),
  array( 'lhs' => 86, 'rhs' => 3 ),
  array( 'lhs' => 86, 'rhs' => 2 ),
  array( 'lhs' => 86, 'rhs' => 3 ),
  array( 'lhs' => 86, 'rhs' => 7 ),
  array( 'lhs' => 86, 'rhs' => 4 ),
  array( 'lhs' => 86, 'rhs' => 8 ),
  array( 'lhs' => 86, 'rhs' => 3 ),
  array( 'lhs' => 86, 'rhs' => 5 ),
  array( 'lhs' => 86, 'rhs' => 6 ),
  array( 'lhs' => 86, 'rhs' => 1 ),
  array( 'lhs' => 91, 'rhs' => 1 ),
  array( 'lhs' => 91, 'rhs' => 4 ),
  array( 'lhs' => 91, 'rhs' => 1 ),
  array( 'lhs' => 91, 'rhs' => 3 ),
  array( 'lhs' => 91, 'rhs' => 3 ),
  array( 'lhs' => 78, 'rhs' => 3 ),
  array( 'lhs' => 97, 'rhs' => 2 ),
  array( 'lhs' => 97, 'rhs' => 0 ),
  array( 'lhs' => 99, 'rhs' => 2 ),
  array( 'lhs' => 99, 'rhs' => 2 ),
  array( 'lhs' => 99, 'rhs' => 2 ),
  array( 'lhs' => 99, 'rhs' => 4 ),
  array( 'lhs' => 99, 'rhs' => 3 ),
  array( 'lhs' => 99, 'rhs' => 5 ),
  array( 'lhs' => 99, 'rhs' => 3 ),
  array( 'lhs' => 99, 'rhs' => 2 ),
  array( 'lhs' => 84, 'rhs' => 1 ),
  array( 'lhs' => 84, 'rhs' => 2 ),
  array( 'lhs' => 100, 'rhs' => 1 ),
  array( 'lhs' => 100, 'rhs' => 3 ),
  array( 'lhs' => 98, 'rhs' => 2 ),
  array( 'lhs' => 96, 'rhs' => 1 ),
  array( 'lhs' => 96, 'rhs' => 2 ),
  array( 'lhs' => 101, 'rhs' => 3 ),
  array( 'lhs' => 101, 'rhs' => 3 ),
  array( 'lhs' => 101, 'rhs' => 5 ),
  array( 'lhs' => 101, 'rhs' => 6 ),
  array( 'lhs' => 101, 'rhs' => 2 ),
  array( 'lhs' => 92, 'rhs' => 4 ),
  array( 'lhs' => 94, 'rhs' => 4 ),
  array( 'lhs' => 95, 'rhs' => 3 ),
  array( 'lhs' => 95, 'rhs' => 1 ),
  array( 'lhs' => 95, 'rhs' => 0 ),
  array( 'lhs' => 79, 'rhs' => 3 ),
  array( 'lhs' => 79, 'rhs' => 2 ),
  array( 'lhs' => 80, 'rhs' => 2 ),
  array( 'lhs' => 80, 'rhs' => 0 ),
  array( 'lhs' => 102, 'rhs' => 2 ),
  array( 'lhs' => 102, 'rhs' => 2 ),
  array( 'lhs' => 81, 'rhs' => 1 ),
  array( 'lhs' => 81, 'rhs' => 2 ),
  array( 'lhs' => 81, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 1 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 2 ),
  array( 'lhs' => 103, 'rhs' => 2 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 2 ),
  array( 'lhs' => 103, 'rhs' => 2 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 103, 'rhs' => 3 ),
  array( 'lhs' => 104, 'rhs' => 1 ),
  array( 'lhs' => 104, 'rhs' => 1 ),
  array( 'lhs' => 104, 'rhs' => 1 ),
  array( 'lhs' => 104, 'rhs' => 1 ),
  array( 'lhs' => 104, 'rhs' => 1 ),
  array( 'lhs' => 104, 'rhs' => 1 ),
  array( 'lhs' => 104, 'rhs' => 1 ),
  array( 'lhs' => 104, 'rhs' => 1 ),
  array( 'lhs' => 105, 'rhs' => 1 ),
  array( 'lhs' => 105, 'rhs' => 1 ),
  array( 'lhs' => 105, 'rhs' => 1 ),
  array( 'lhs' => 87, 'rhs' => 3 ),
  array( 'lhs' => 106, 'rhs' => 1 ),
  array( 'lhs' => 106, 'rhs' => 3 ),
  array( 'lhs' => 106, 'rhs' => 0 ),
  array( 'lhs' => 107, 'rhs' => 3 ),
  array( 'lhs' => 107, 'rhs' => 3 ),
  array( 'lhs' => 107, 'rhs' => 1 ),
  array( 'lhs' => 93, 'rhs' => 2 ),
  array( 'lhs' => 93, 'rhs' => 1 ),
  array( 'lhs' => 108, 'rhs' => 3 ),
  array( 'lhs' => 108, 'rhs' => 3 ),
  array( 'lhs' => 108, 'rhs' => 2 ),
  array( 'lhs' => 108, 'rhs' => 3 ),
  array( 'lhs' => 108, 'rhs' => 1 ),
  array( 'lhs' => 108, 'rhs' => 2 ),
  array( 'lhs' => 108, 'rhs' => 2 ),
  array( 'lhs' => 108, 'rhs' => 2 ),
  array( 'lhs' => 108, 'rhs' => 1 ),
  array( 'lhs' => 75, 'rhs' => 2 ),
  array( 'lhs' => 75, 'rhs' => 1 ),
  array( 'lhs' => 109, 'rhs' => 1 ),
  array( 'lhs' => 109, 'rhs' => 1 ),
    );

    /**
     * The following table contains a mapping of reduce action to method name
     * that handles the reduction.
     * 
     * If a rule is not set, it has no handler.
     */
    static public $yyReduceMap = array(
        0 => 0,
        39 => 0,
        46 => 0,
        47 => 0,
        49 => 0,
        50 => 0,
        51 => 0,
        67 => 0,
        136 => 0,
        1 => 1,
        36 => 1,
        43 => 1,
        44 => 1,
        45 => 1,
        81 => 1,
        104 => 1,
        143 => 1,
        152 => 1,
        154 => 1,
        155 => 1,
        156 => 1,
        2 => 2,
        71 => 2,
        142 => 2,
        150 => 2,
        153 => 2,
        3 => 3,
        4 => 4,
        5 => 5,
        6 => 6,
        7 => 7,
        8 => 8,
        9 => 9,
        10 => 10,
        11 => 11,
        12 => 12,
        13 => 13,
        14 => 14,
        15 => 15,
        16 => 16,
        17 => 17,
        18 => 18,
        19 => 19,
        20 => 20,
        21 => 21,
        22 => 22,
        28 => 22,
        96 => 22,
        141 => 22,
        23 => 23,
        24 => 24,
        25 => 25,
        26 => 26,
        27 => 27,
        29 => 29,
        30 => 30,
        31 => 31,
        32 => 32,
        33 => 33,
        34 => 34,
        35 => 35,
        37 => 37,
        38 => 38,
        40 => 40,
        41 => 41,
        42 => 42,
        48 => 48,
        52 => 52,
        53 => 53,
        54 => 54,
        56 => 54,
        55 => 55,
        57 => 57,
        58 => 58,
        59 => 59,
        60 => 60,
        61 => 61,
        62 => 62,
        63 => 63,
        64 => 64,
        65 => 65,
        66 => 66,
        68 => 68,
        69 => 69,
        70 => 70,
        72 => 72,
        101 => 72,
        73 => 73,
        74 => 74,
        75 => 75,
        76 => 76,
        79 => 76,
        77 => 77,
        78 => 78,
        80 => 80,
        82 => 82,
        83 => 83,
        84 => 84,
        106 => 84,
        85 => 85,
        86 => 86,
        87 => 87,
        88 => 88,
        89 => 89,
        90 => 90,
        91 => 91,
        92 => 92,
        93 => 93,
        94 => 94,
        95 => 95,
        97 => 97,
        98 => 98,
        99 => 99,
        100 => 100,
        102 => 102,
        103 => 103,
        105 => 105,
        107 => 107,
        108 => 108,
        111 => 108,
        122 => 108,
        109 => 109,
        110 => 110,
        112 => 112,
        113 => 113,
        114 => 114,
        119 => 114,
        115 => 115,
        118 => 115,
        116 => 116,
        121 => 116,
        117 => 117,
        120 => 117,
        123 => 123,
        124 => 124,
        125 => 125,
        126 => 126,
        127 => 127,
        128 => 128,
        129 => 129,
        130 => 130,
        131 => 131,
        132 => 132,
        133 => 133,
        134 => 134,
        135 => 135,
        137 => 137,
        138 => 138,
        139 => 139,
        140 => 140,
        144 => 144,
        145 => 145,
        146 => 146,
        147 => 147,
        148 => 148,
        149 => 149,
        151 => 151,
    );
    /* Beginning here are the reduction cases.  A typical example
    ** follows:
    **  #line <lineno> <grammarfile>
    **   function yy_r0($yymsp){ ... }           // User supplied code
    **  #line <lineno> <thisfile>
    */
#line 79 "internal.templateparser.y"
    function yy_r0(){ $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;     }
#line 1943 "internal.templateparser.php"
#line 85 "internal.templateparser.y"
    function yy_r1(){$this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;    }
#line 1946 "internal.templateparser.php"
#line 87 "internal.templateparser.y"
    function yy_r2(){$this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;    }
#line 1949 "internal.templateparser.php"
#line 93 "internal.templateparser.y"
    function yy_r3(){if ($this->compiler->has_code) {
                                            $tmp =''; foreach ($this->prefix_code as $code) {$tmp.=$code;} $this->prefix_code=array();
                                            $this->_retvalue = $this->cacher->processNocacheCode($tmp.$this->yystack[$this->yyidx + 0]->minor, $this->compiler,$this->nocache,true);
                                         } else { $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;} $this->nocache=false;    }
#line 1955 "internal.templateparser.php"
#line 98 "internal.templateparser.y"
    function yy_r4(){ preg_match('/\s*/',$this->yystack[$this->yyidx + -2]->minor,$s); $this->_retvalue = $s[0];    }
#line 1958 "internal.templateparser.php"
#line 101 "internal.templateparser.y"
    function yy_r5(){preg_match('/\s*/',$this->yystack[$this->yyidx + -2]->minor,$s); preg_match('/\s*/',$this->yystack[$this->yyidx + 0]->minor,$s2); $this->_retvalue = $s[0].$this->cacher->processNocacheCode($this->yystack[$this->yyidx + -1]->minor.$s2[0], $this->compiler,false,false);    }
#line 1961 "internal.templateparser.php"
#line 103 "internal.templateparser.y"
    function yy_r6(){preg_match('/\s*/',$this->yystack[$this->yyidx + 0]->minor,$s); $this->_retvalue = $s[0].$this->cacher->processNocacheCode($this->smarty->left_delimiter, $this->compiler,false,false);    }
#line 1964 "internal.templateparser.php"
#line 105 "internal.templateparser.y"
    function yy_r7(){preg_match('/\s*/',$this->yystack[$this->yyidx + 0]->minor,$s); $this->_retvalue = $s[0].$this->cacher->processNocacheCode($this->smarty->right_delimiter, $this->compiler,false,false);    }
#line 1967 "internal.templateparser.php"
#line 107 "internal.templateparser.y"
    function yy_r8(){if ($this->sec_obj->php_handling == SMARTY_PHP_PASSTHRU) {
                                       $this->_retvalue = $this->cacher->processNocacheCode("<?php echo '<?php".str_replace("'","\'",$this->yystack[$this->yyidx + -1]->minor)."?>';?>\n", $this->compiler, false, false);
                                      } elseif ($this->sec_obj->php_handling == SMARTY_PHP_QUOTE) {
                                       $this->_retvalue = $this->cacher->processNocacheCode(htmlspecialchars('<?php'.$this->yystack[$this->yyidx + -1]->minor.'?>', ENT_QUOTES), $this->compiler, false, false);
                                      }elseif ($this->sec_obj->php_handling == SMARTY_PHP_ALLOW) {
                                       $this->_retvalue = $this->cacher->processNocacheCode('<?php'.$this->yystack[$this->yyidx + -1]->minor.'?>', $this->compiler, false,true);
                                      }elseif ($this->sec_obj->php_handling == SMARTY_PHP_REMOVE) {
                                       $this->_retvalue = '';
                                      }
                                         }
#line 1979 "internal.templateparser.php"
#line 118 "internal.templateparser.y"
    function yy_r9(){preg_match('/\s*/',$this->yystack[$this->yyidx + -3]->minor,$s); $this->_retvalue = $s[0];
                                      if ($this->sec_obj->php_handling == SMARTY_PHP_PASSTHRU || $this->sec_obj->php_handling == SMARTY_PHP_ALLOW) {
                                       $this->_retvalue .= $this->cacher->processNocacheCode("<?php echo '<?=$".$this->yystack[$this->yyidx + -1]->minor."?>'?>\n", $this->compiler, false, false);
                                      } elseif ($this->sec_obj->php_handling == SMARTY_PHP_QUOTE) {
                                       $this->_retvalue .= $this->cacher->processNocacheCode(htmlspecialchars('<?=$'.$this->yystack[$this->yyidx + -1]->minor.'?>', ENT_QUOTES), $this->compiler, false, false);
                                      }elseif ($this->sec_obj == SMARTY_PHP_REMOVE) {
                                       $this->_retvalue .= '';
                                      }
                                         }
#line 1990 "internal.templateparser.php"
#line 129 "internal.templateparser.y"
    function yy_r10(){preg_match('/\s*/',$this->yystack[$this->yyidx + 0]->minor,$s); $this->_retvalue = $s[0].$this->cacher->processNocacheCode("<?php echo '<?xml';?>", $this->compiler, true, true);    }
#line 1993 "internal.templateparser.php"
#line 130 "internal.templateparser.y"
    function yy_r11(){$this->_retvalue = $this->cacher->processNocacheCode("<?php echo '?>';?>\n", $this->compiler, true, true);    }
#line 1996 "internal.templateparser.php"
#line 132 "internal.templateparser.y"
    function yy_r12(){$this->_retvalue = $this->cacher->processNocacheCode($this->yystack[$this->yyidx + 0]->minor, $this->compiler,false,false);    }
#line 1999 "internal.templateparser.php"
#line 139 "internal.templateparser.y"
    function yy_r13(){ preg_match('/\s*/',$this->yystack[$this->yyidx + -3]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag('print_expression',array_merge(array('value'=>$this->yystack[$this->yyidx + -2]->minor),$this->yystack[$this->yyidx + -1]->minor));    }
#line 2002 "internal.templateparser.php"
#line 141 "internal.templateparser.y"
    function yy_r14(){ preg_match('/\s*/',$this->yystack[$this->yyidx + -5]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag('assign',array_merge(array('value'=>$this->yystack[$this->yyidx + -2]->minor),$this->yystack[$this->yyidx + -4]->minor,$this->yystack[$this->yyidx + -1]->minor));    }
#line 2005 "internal.templateparser.php"
#line 143 "internal.templateparser.y"
    function yy_r15(){ preg_match('/\s*/',$this->yystack[$this->yyidx + -3]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag($this->yystack[$this->yyidx + -2]->minor,$this->yystack[$this->yyidx + -1]->minor);    }
#line 2008 "internal.templateparser.php"
#line 145 "internal.templateparser.y"
    function yy_r16(){ preg_match('/\s*/',$this->yystack[$this->yyidx + -5]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag($this->yystack[$this->yyidx + -4]->minor,array_merge(array('object_methode'=>$this->yystack[$this->yyidx + -2]->minor),$this->yystack[$this->yyidx + -1]->minor));    }
#line 2011 "internal.templateparser.php"
#line 147 "internal.templateparser.y"
    function yy_r17(){ preg_match('/\s*/',$this->yystack[$this->yyidx + -5]->minor,$s); $this->_retvalue = $s[0].'<?php ob_start();?>'.$this->compiler->compileTag($this->yystack[$this->yyidx + -4]->minor,$this->yystack[$this->yyidx + -1]->minor).'<?php echo ';
															                                   if ($this->smarty->plugin_handler->loadSmartyPlugin($this->yystack[$this->yyidx + -3]->minor[0],'modifier')) {
                                                                      $this->_retvalue .= "\$_smarty_tpl->smarty->plugin_handler->executeModifier('".$this->yystack[$this->yyidx + -3]->minor[0] . "',array(ob_get_clean()" . $this->yystack[$this->yyidx + -2]->minor. "),".$this->yystack[$this->yyidx + -3]->minor[1].");?>";
                                                                 } else {
                                                                   if (is_callable($this->yystack[$this->yyidx + -3]->minor[0])) {
																					                            if (!$this->template->security || $this->smarty->security_handler->isTrustedModifier($this->yystack[$this->yyidx + -3]->minor[0], $this->compiler)) {
                                                                         $this->_retvalue .= "\$_smarty_tpl->smarty->plugin_handler->executeModifier('".$this->yystack[$this->yyidx + -3]->minor[0] . "',array(ob_get_clean()" . $this->yystack[$this->yyidx + -2]->minor. "),".$this->yystack[$this->yyidx + -3]->minor[1].");?>";
																					                            }
																					                         } else {
                                                                      $this->compiler->trigger_template_error ("unknown modifier \"" . $this->yystack[$this->yyidx + -3]->minor[0] . "\"");
                                                                 }
                                                              }
                                                                        }
#line 2026 "internal.templateparser.php"
#line 161 "internal.templateparser.y"
    function yy_r18(){if (!in_array($this->yystack[$this->yyidx + -3]->minor,array('if','elseif','while'))) {
                                                            $this->compiler->trigger_template_error ("wrong syntax for tag \"" . $this->yystack[$this->yyidx + -3]->minor . "\""); 
                                                            }
                                                           preg_match('/\s*/',$this->yystack[$this->yyidx + -4]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag($this->yystack[$this->yyidx + -3]->minor,array('if condition'=>$this->yystack[$this->yyidx + -1]->minor));    }
#line 2032 "internal.templateparser.php"
#line 165 "internal.templateparser.y"
    function yy_r19(){ if (!in_array($this->yystack[$this->yyidx + -3]->minor,array('if','elseif','while'))) {
                                                            $this->compiler->trigger_template_error ("wrong syntax for tag \"" . $this->yystack[$this->yyidx + -3]->minor . "\""); 
                                                            }
                                                           preg_match('/\s*/',$this->yystack[$this->yyidx + -4]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag($this->yystack[$this->yyidx + -3]->minor,array('if condition'=>$this->yystack[$this->yyidx + -1]->minor));    }
#line 2038 "internal.templateparser.php"
#line 170 "internal.templateparser.y"
    function yy_r20(){
                                                            if ($this->yystack[$this->yyidx + -9]->minor != 'for') {
                                                               $this->compiler->trigger_template_error ("wrong syntax for tag \"" . $this->yystack[$this->yyidx + -9]->minor . "\""); 
                                                            }
                                                            preg_match('/\s*/',$this->yystack[$this->yyidx + -10]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag($this->yystack[$this->yyidx + -9]->minor,array('start'=>$this->yystack[$this->yyidx + -7]->minor,'ifexp'=>$this->yystack[$this->yyidx + -5]->minor,'varloop'=>$this->yystack[$this->yyidx + -2]->minor,'loop'=>$this->yystack[$this->yyidx + -1]->minor));    }
#line 2045 "internal.templateparser.php"
#line 175 "internal.templateparser.y"
    function yy_r21(){ $this->_retvalue = '='.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2048 "internal.templateparser.php"
#line 176 "internal.templateparser.y"
    function yy_r22(){ $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;    }
#line 2051 "internal.templateparser.php"
#line 178 "internal.templateparser.y"
    function yy_r23(){
                                                            if ($this->yystack[$this->yyidx + -6]->minor != 'foreach') {
                                                               $this->compiler->trigger_template_error ("wrong syntax for tag \"" . $this->yystack[$this->yyidx + -6]->minor . "\""); 
                                                            }
                                                            preg_match('/\s*/',$this->yystack[$this->yyidx + -7]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag($this->yystack[$this->yyidx + -6]->minor,array('from'=>$this->yystack[$this->yyidx + -4]->minor,'item'=>$this->yystack[$this->yyidx + -1]->minor));    }
#line 2058 "internal.templateparser.php"
#line 183 "internal.templateparser.y"
    function yy_r24(){ 
                                                            if ($this->yystack[$this->yyidx + -6]->minor != 'foreach') {
                                                               $this->compiler->trigger_template_error ("wrong syntax for tag \"" . $this->yystack[$this->yyidx + -6]->minor . "\""); 
                                                            }
                                                            preg_match('/\s*/',$this->yystack[$this->yyidx + -7]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag($this->yystack[$this->yyidx + -6]->minor,array('from'=>$this->yystack[$this->yyidx + -4]->minor,'item'=>$this->yystack[$this->yyidx + -1]->minor));    }
#line 2065 "internal.templateparser.php"
#line 190 "internal.templateparser.y"
    function yy_r25(){ preg_match('/\s*/',$this->yystack[$this->yyidx + -3]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag($this->yystack[$this->yyidx + -2]->minor.'close',$this->yystack[$this->yyidx + -1]->minor);    }
#line 2068 "internal.templateparser.php"
#line 192 "internal.templateparser.y"
    function yy_r26(){ preg_match('/\s*/',$this->yystack[$this->yyidx + -4]->minor,$s); $this->_retvalue = $s[0].$this->compiler->compileTag($this->yystack[$this->yyidx + -3]->minor.'close',array('object_methode'=>$this->yystack[$this->yyidx + -1]->minor));    }
#line 2071 "internal.templateparser.php"
#line 199 "internal.templateparser.y"
    function yy_r27(){ $this->_retvalue = array_merge($this->yystack[$this->yyidx + -1]->minor,$this->yystack[$this->yyidx + 0]->minor);    }
#line 2074 "internal.templateparser.php"
#line 203 "internal.templateparser.y"
    function yy_r29(){ $this->_retvalue = array();    }
#line 2077 "internal.templateparser.php"
#line 206 "internal.templateparser.y"
    function yy_r30(){ $this->_retvalue = array($this->yystack[$this->yyidx + -2]->minor=>$this->yystack[$this->yyidx + 0]->minor);    }
#line 2080 "internal.templateparser.php"
#line 207 "internal.templateparser.y"
    function yy_r31(){ $this->_retvalue = array($this->yystack[$this->yyidx + 0]->minor=>'true');    }
#line 2083 "internal.templateparser.php"
#line 212 "internal.templateparser.y"
    function yy_r32(){ $this->_retvalue = array($this->yystack[$this->yyidx + 0]->minor);    }
#line 2086 "internal.templateparser.php"
#line 213 "internal.templateparser.y"
    function yy_r33(){ $this->yystack[$this->yyidx + -2]->minor[]=$this->yystack[$this->yyidx + 0]->minor; $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor;    }
#line 2089 "internal.templateparser.php"
#line 215 "internal.templateparser.y"
    function yy_r34(){ $this->_retvalue = array('var' => $this->yystack[$this->yyidx + -2]->minor, 'value'=>$this->yystack[$this->yyidx + 0]->minor);    }
#line 2092 "internal.templateparser.php"
#line 221 "internal.templateparser.y"
    function yy_r35(){ $this->_retvalue = '\''.$this->yystack[$this->yyidx + 0]->minor.'\'';     }
#line 2095 "internal.templateparser.php"
#line 225 "internal.templateparser.y"
    function yy_r37(){$this->_retvalue = '$_smarty_tpl->getStreamVariable(\''. $this->yystack[$this->yyidx + -2]->minor .'://'. $this->yystack[$this->yyidx + 0]->minor . '\')';    }
#line 2098 "internal.templateparser.php"
#line 226 "internal.templateparser.y"
    function yy_r38(){            
                                                            if ($this->smarty->plugin_handler->loadSmartyPlugin($this->yystack[$this->yyidx + -1]->minor[0],'modifier')) {
                                                                      $this->_retvalue = "\$_smarty_tpl->smarty->plugin_handler->executeModifier('".$this->yystack[$this->yyidx + -1]->minor[0] . "',array(". $this->yystack[$this->yyidx + -2]->minor . $this->yystack[$this->yyidx + 0]->minor. "),".$this->yystack[$this->yyidx + -1]->minor[1].")";
                                                                 } else {
                                                                   if (is_callable($this->yystack[$this->yyidx + -1]->minor[0])) {
																					                            if (!$this->template->security || $this->smarty->security_handler->isTrustedModifier($this->yystack[$this->yyidx + -1]->minor[0], $this->compiler)) {
                                                                         $this->_retvalue = "\$_smarty_tpl->smarty->plugin_handler->executeModifier('".$this->yystack[$this->yyidx + -1]->minor[0] . "',array(". $this->yystack[$this->yyidx + -2]->minor . $this->yystack[$this->yyidx + 0]->minor. "),".$this->yystack[$this->yyidx + -1]->minor[1].")";
																					                            }
																					                         } else {
                                                                      $this->compiler->trigger_template_error ("unknown modifier \"" . $this->yystack[$this->yyidx + -1]->minor[0] . "\"");
                                                                 }
                                                              }
                                                                }
#line 2113 "internal.templateparser.php"
#line 243 "internal.templateparser.y"
    function yy_r40(){ $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;     }
#line 2116 "internal.templateparser.php"
#line 245 "internal.templateparser.y"
    function yy_r41(){ $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor . $this->yystack[$this->yyidx + -1]->minor . $this->yystack[$this->yyidx + 0]->minor;     }
#line 2119 "internal.templateparser.php"
#line 247 "internal.templateparser.y"
    function yy_r42(){ $this->_retvalue = '('. $this->yystack[$this->yyidx + -2]->minor . ').(' . $this->yystack[$this->yyidx + 0]->minor. ')';     }
#line 2122 "internal.templateparser.php"
#line 267 "internal.templateparser.y"
    function yy_r48(){ $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.'.'.$this->yystack[$this->yyidx + 0]->minor;     }
#line 2125 "internal.templateparser.php"
#line 275 "internal.templateparser.y"
    function yy_r52(){ $this->_retvalue = "(". $this->yystack[$this->yyidx + -1]->minor .")";     }
#line 2128 "internal.templateparser.php"
#line 277 "internal.templateparser.y"
    function yy_r53(){ $this->_retvalue = "'".$this->yystack[$this->yyidx + -1]->minor."'";     }
#line 2131 "internal.templateparser.php"
#line 278 "internal.templateparser.y"
    function yy_r54(){ $this->_retvalue = "''";     }
#line 2134 "internal.templateparser.php"
#line 280 "internal.templateparser.y"
    function yy_r55(){ $this->_retvalue = '"'.$this->yystack[$this->yyidx + -1]->minor.'"';     }
#line 2137 "internal.templateparser.php"
#line 283 "internal.templateparser.y"
    function yy_r57(){ $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.'::'.$this->yystack[$this->yyidx + 0]->minor;     }
#line 2140 "internal.templateparser.php"
#line 284 "internal.templateparser.y"
    function yy_r58(){ $this->prefix_number++; $this->prefix_code[] = '<?php $_tmp'.$this->prefix_number.'=$_smarty_tpl->getVariable(\''. $this->yystack[$this->yyidx + -3]->minor .'\')->value;?>'; $this->_retvalue = $this->yystack[$this->yyidx + -6]->minor.'::$_tmp'.$this->prefix_number.'('. $this->yystack[$this->yyidx + -1]->minor .')';     }
#line 2143 "internal.templateparser.php"
#line 286 "internal.templateparser.y"
    function yy_r59(){ $this->_retvalue = $this->yystack[$this->yyidx + -3]->minor.'::'.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;     }
#line 2146 "internal.templateparser.php"
#line 287 "internal.templateparser.y"
    function yy_r60(){ $this->prefix_number++; $this->prefix_code[] = '<?php $_tmp'.$this->prefix_number.'=$_smarty_tpl->getVariable(\''. $this->yystack[$this->yyidx + -4]->minor .'\')->value;?>'; $this->_retvalue = $this->yystack[$this->yyidx + -7]->minor.'::$_tmp'.$this->prefix_number.'('. $this->yystack[$this->yyidx + -2]->minor .')'.$this->yystack[$this->yyidx + 0]->minor;     }
#line 2149 "internal.templateparser.php"
#line 289 "internal.templateparser.y"
    function yy_r61(){ $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.'::'.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2152 "internal.templateparser.php"
#line 291 "internal.templateparser.y"
    function yy_r62(){ $this->_retvalue = $this->yystack[$this->yyidx + -4]->minor.'::$'.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2155 "internal.templateparser.php"
#line 293 "internal.templateparser.y"
    function yy_r63(){ $this->_retvalue = $this->yystack[$this->yyidx + -5]->minor.'::$'.$this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2158 "internal.templateparser.php"
#line 295 "internal.templateparser.y"
    function yy_r64(){ $this->prefix_number++; $this->prefix_code[] = '<?php ob_start();?>'.$this->yystack[$this->yyidx + 0]->minor.'<?php $_tmp'.$this->prefix_number.'=ob_get_clean();?>'; $this->_retvalue = '$_tmp'.$this->prefix_number;     }
#line 2161 "internal.templateparser.php"
#line 301 "internal.templateparser.y"
    function yy_r65(){if ($this->yystack[$this->yyidx + 0]->minor['var'] == '\'smarty\'') { $this->_retvalue =  $this->compiler->compileTag('internal_smarty_var',$this->yystack[$this->yyidx + 0]->minor['index']);} else {
                                                         $this->_retvalue = '$_smarty_tpl->getVariable('. $this->yystack[$this->yyidx + 0]->minor['var'] .')->value'.$this->yystack[$this->yyidx + 0]->minor['index']; $this->nocache=$this->template->getVariable(trim($this->yystack[$this->yyidx + 0]->minor['var'],"'"))->nocache;}    }
#line 2165 "internal.templateparser.php"
#line 304 "internal.templateparser.y"
    function yy_r66(){ $this->_retvalue = '$_smarty_tpl->getVariable('. $this->yystack[$this->yyidx + -2]->minor .')->'.$this->yystack[$this->yyidx + 0]->minor; $this->nocache=$this->template->getVariable(trim($this->yystack[$this->yyidx + -2]->minor,"'"))->nocache;    }
#line 2168 "internal.templateparser.php"
#line 308 "internal.templateparser.y"
    function yy_r68(){$this->_retvalue = '$_smarty_tpl->getConfigVariable(\''. $this->yystack[$this->yyidx + -1]->minor .'\')';    }
#line 2171 "internal.templateparser.php"
#line 309 "internal.templateparser.y"
    function yy_r69(){$this->_retvalue = '$_smarty_tpl->getConfigVariable('. $this->yystack[$this->yyidx + -1]->minor .')';    }
#line 2174 "internal.templateparser.php"
#line 312 "internal.templateparser.y"
    function yy_r70(){$this->_retvalue = array('var'=>$this->yystack[$this->yyidx + -1]->minor, 'index'=>$this->yystack[$this->yyidx + 0]->minor);    }
#line 2177 "internal.templateparser.php"
#line 320 "internal.templateparser.y"
    function yy_r72(){return;    }
#line 2180 "internal.templateparser.php"
#line 324 "internal.templateparser.y"
    function yy_r73(){ $this->_retvalue = "['". $this->yystack[$this->yyidx + 0]->minor ."']";    }
#line 2183 "internal.templateparser.php"
#line 325 "internal.templateparser.y"
    function yy_r74(){ $this->_retvalue = "[". $this->yystack[$this->yyidx + 0]->minor ."]";    }
#line 2186 "internal.templateparser.php"
#line 326 "internal.templateparser.y"
    function yy_r75(){ $this->_retvalue = "[".$this->yystack[$this->yyidx + 0]->minor."]";    }
#line 2189 "internal.templateparser.php"
#line 327 "internal.templateparser.y"
    function yy_r76(){ $this->_retvalue = "[". $this->yystack[$this->yyidx + -1]->minor ."]";    }
#line 2192 "internal.templateparser.php"
#line 329 "internal.templateparser.y"
    function yy_r77(){ $this->_retvalue = '['.$this->compiler->compileTag('internal_smarty_var','[\'section\'][\''.$this->yystack[$this->yyidx + -1]->minor.'\'][\'index\']').']';    }
#line 2195 "internal.templateparser.php"
#line 330 "internal.templateparser.y"
    function yy_r78(){ $this->_retvalue = '['.$this->compiler->compileTag('internal_smarty_var','[\'section\'][\''.$this->yystack[$this->yyidx + -3]->minor.'\'][\''.$this->yystack[$this->yyidx + -1]->minor.'\']').']';    }
#line 2198 "internal.templateparser.php"
#line 334 "internal.templateparser.y"
    function yy_r80(){$this->_retvalue = '';    }
#line 2201 "internal.templateparser.php"
#line 342 "internal.templateparser.y"
    function yy_r82(){$this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.'.'.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2204 "internal.templateparser.php"
#line 344 "internal.templateparser.y"
    function yy_r83(){$this->_retvalue = '\''.$this->yystack[$this->yyidx + 0]->minor.'\'';    }
#line 2207 "internal.templateparser.php"
#line 346 "internal.templateparser.y"
    function yy_r84(){$this->_retvalue = '('.$this->yystack[$this->yyidx + -1]->minor.')';    }
#line 2210 "internal.templateparser.php"
#line 351 "internal.templateparser.y"
    function yy_r85(){ if ($this->yystack[$this->yyidx + -1]->minor['var'] == '\'smarty\'') { $this->_retvalue =  $this->compiler->compileTag('internal_smarty_var',$this->yystack[$this->yyidx + -1]->minor['index']).$this->yystack[$this->yyidx + 0]->minor;} else {
                                                         $this->_retvalue = '$_smarty_tpl->getVariable('. $this->yystack[$this->yyidx + -1]->minor['var'] .')->value'.$this->yystack[$this->yyidx + -1]->minor['index'].$this->yystack[$this->yyidx + 0]->minor; $this->nocache=$this->template->getVariable(trim($this->yystack[$this->yyidx + -1]->minor['var'],"'"))->nocache;}    }
#line 2214 "internal.templateparser.php"
#line 354 "internal.templateparser.y"
    function yy_r86(){$this->_retvalue  = $this->yystack[$this->yyidx + 0]->minor;     }
#line 2217 "internal.templateparser.php"
#line 356 "internal.templateparser.y"
    function yy_r87(){$this->_retvalue  = $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;     }
#line 2220 "internal.templateparser.php"
#line 358 "internal.templateparser.y"
    function yy_r88(){ $this->_retvalue = '->'.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2223 "internal.templateparser.php"
#line 359 "internal.templateparser.y"
    function yy_r89(){ $this->_retvalue = '->{'.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor.'}';    }
#line 2226 "internal.templateparser.php"
#line 360 "internal.templateparser.y"
    function yy_r90(){ $this->_retvalue = '->{'.$this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + 0]->minor.'}';    }
#line 2229 "internal.templateparser.php"
#line 361 "internal.templateparser.y"
    function yy_r91(){ $this->_retvalue = '->{\''.$this->yystack[$this->yyidx + -4]->minor.'\'.'.$this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + 0]->minor.'}';    }
#line 2232 "internal.templateparser.php"
#line 363 "internal.templateparser.y"
    function yy_r92(){ $this->_retvalue = '->'.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2235 "internal.templateparser.php"
#line 369 "internal.templateparser.y"
    function yy_r93(){if (!$this->template->security || $this->smarty->security_handler->isTrustedPhpFunction($this->yystack[$this->yyidx + -3]->minor, $this->compiler)) {
																					            if ($this->yystack[$this->yyidx + -3]->minor == 'isset' || $this->yystack[$this->yyidx + -3]->minor == 'empty' || $this->yystack[$this->yyidx + -3]->minor == 'array' || is_callable($this->yystack[$this->yyidx + -3]->minor)) {
																					                $this->_retvalue = $this->yystack[$this->yyidx + -3]->minor . "(". $this->yystack[$this->yyidx + -1]->minor .")";
																					            } else {
                                                       $this->compiler->trigger_template_error ("unknown function \"" . $this->yystack[$this->yyidx + -3]->minor . "\"");
                                                      }
                                                    }    }
#line 2244 "internal.templateparser.php"
#line 380 "internal.templateparser.y"
    function yy_r94(){ $this->_retvalue = $this->yystack[$this->yyidx + -3]->minor . "(". $this->yystack[$this->yyidx + -1]->minor .")";    }
#line 2247 "internal.templateparser.php"
#line 384 "internal.templateparser.y"
    function yy_r95(){ $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.",".$this->yystack[$this->yyidx + 0]->minor;    }
#line 2250 "internal.templateparser.php"
#line 388 "internal.templateparser.y"
    function yy_r97(){ return;    }
#line 2253 "internal.templateparser.php"
#line 393 "internal.templateparser.y"
    function yy_r98(){ $this->_retvalue =  array($this->yystack[$this->yyidx + 0]->minor,'false');    }
#line 2256 "internal.templateparser.php"
#line 394 "internal.templateparser.y"
    function yy_r99(){ $this->_retvalue =  array($this->yystack[$this->yyidx + 0]->minor,'true');    }
#line 2259 "internal.templateparser.php"
#line 401 "internal.templateparser.y"
    function yy_r100(){ $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2262 "internal.templateparser.php"
#line 405 "internal.templateparser.y"
    function yy_r102(){$this->_retvalue = ','.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2265 "internal.templateparser.php"
#line 406 "internal.templateparser.y"
    function yy_r103(){$this->_retvalue = ',\''.$this->yystack[$this->yyidx + 0]->minor.'\'';    }
#line 2268 "internal.templateparser.php"
#line 413 "internal.templateparser.y"
    function yy_r105(){$this->_retvalue = '!'.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2271 "internal.templateparser.php"
#line 418 "internal.templateparser.y"
    function yy_r107(){$this->_retvalue =$this->yystack[$this->yyidx + 0]->minor;    }
#line 2274 "internal.templateparser.php"
#line 419 "internal.templateparser.y"
    function yy_r108(){$this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2277 "internal.templateparser.php"
#line 420 "internal.templateparser.y"
    function yy_r109(){$this->_retvalue = 'in_array('.$this->yystack[$this->yyidx + -2]->minor.','.$this->yystack[$this->yyidx + 0]->minor.')';    }
#line 2280 "internal.templateparser.php"
#line 421 "internal.templateparser.y"
    function yy_r110(){$this->_retvalue = 'in_array('.$this->yystack[$this->yyidx + -2]->minor.',(array)'.$this->yystack[$this->yyidx + 0]->minor.')';    }
#line 2283 "internal.templateparser.php"
#line 423 "internal.templateparser.y"
    function yy_r112(){$this->_retvalue = '!('.$this->yystack[$this->yyidx + -2]->minor.' % '.$this->yystack[$this->yyidx + 0]->minor.')';    }
#line 2286 "internal.templateparser.php"
#line 424 "internal.templateparser.y"
    function yy_r113(){$this->_retvalue = '('.$this->yystack[$this->yyidx + -2]->minor.' % '.$this->yystack[$this->yyidx + 0]->minor.')';    }
#line 2289 "internal.templateparser.php"
#line 425 "internal.templateparser.y"
    function yy_r114(){$this->_retvalue = '!(1 & '.$this->yystack[$this->yyidx + -1]->minor.')';    }
#line 2292 "internal.templateparser.php"
#line 426 "internal.templateparser.y"
    function yy_r115(){$this->_retvalue = '(1 & '.$this->yystack[$this->yyidx + -1]->minor.')';    }
#line 2295 "internal.templateparser.php"
#line 427 "internal.templateparser.y"
    function yy_r116(){$this->_retvalue = '!(1 & '.$this->yystack[$this->yyidx + -2]->minor.' / '.$this->yystack[$this->yyidx + 0]->minor.')';    }
#line 2298 "internal.templateparser.php"
#line 428 "internal.templateparser.y"
    function yy_r117(){$this->_retvalue = '(1 & '.$this->yystack[$this->yyidx + -2]->minor.' / '.$this->yystack[$this->yyidx + 0]->minor.')';    }
#line 2301 "internal.templateparser.php"
#line 434 "internal.templateparser.y"
    function yy_r123(){$this->prefix_number++; $this->prefix_code[] = '<?php $_tmp'.$this->prefix_number.'='.$this->yystack[$this->yyidx + 0]->minor.';?>'; $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + -1]->minor.'$_tmp'.$this->prefix_number;    }
#line 2304 "internal.templateparser.php"
#line 436 "internal.templateparser.y"
    function yy_r124(){$this->_retvalue = '==';    }
#line 2307 "internal.templateparser.php"
#line 437 "internal.templateparser.y"
    function yy_r125(){$this->_retvalue = '!=';    }
#line 2310 "internal.templateparser.php"
#line 438 "internal.templateparser.y"
    function yy_r126(){$this->_retvalue = '>';    }
#line 2313 "internal.templateparser.php"
#line 439 "internal.templateparser.y"
    function yy_r127(){$this->_retvalue = '<';    }
#line 2316 "internal.templateparser.php"
#line 440 "internal.templateparser.y"
    function yy_r128(){$this->_retvalue = '>=';    }
#line 2319 "internal.templateparser.php"
#line 441 "internal.templateparser.y"
    function yy_r129(){$this->_retvalue = '<=';    }
#line 2322 "internal.templateparser.php"
#line 442 "internal.templateparser.y"
    function yy_r130(){$this->_retvalue = '===';    }
#line 2325 "internal.templateparser.php"
#line 443 "internal.templateparser.y"
    function yy_r131(){$this->_retvalue = '!==';    }
#line 2328 "internal.templateparser.php"
#line 445 "internal.templateparser.y"
    function yy_r132(){$this->_retvalue = '&&';    }
#line 2331 "internal.templateparser.php"
#line 446 "internal.templateparser.y"
    function yy_r133(){$this->_retvalue = '||';    }
#line 2334 "internal.templateparser.php"
#line 447 "internal.templateparser.y"
    function yy_r134(){$this->_retvalue = ' XOR ';    }
#line 2337 "internal.templateparser.php"
#line 452 "internal.templateparser.y"
    function yy_r135(){ $this->_retvalue = 'array('.$this->yystack[$this->yyidx + -1]->minor.')';    }
#line 2340 "internal.templateparser.php"
#line 454 "internal.templateparser.y"
    function yy_r137(){ $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.','.$this->yystack[$this->yyidx + 0]->minor;     }
#line 2343 "internal.templateparser.php"
#line 455 "internal.templateparser.y"
    function yy_r138(){ return;     }
#line 2346 "internal.templateparser.php"
#line 456 "internal.templateparser.y"
    function yy_r139(){ $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.'=>'.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2349 "internal.templateparser.php"
#line 457 "internal.templateparser.y"
    function yy_r140(){ $this->_retvalue = '\''.$this->yystack[$this->yyidx + -2]->minor.'\'=>'.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2352 "internal.templateparser.php"
#line 465 "internal.templateparser.y"
    function yy_r144(){$this->_retvalue = "`".$this->yystack[$this->yyidx + -1]->minor."`";    }
#line 2355 "internal.templateparser.php"
#line 466 "internal.templateparser.y"
    function yy_r145(){$this->_retvalue = '".'.$this->yystack[$this->yyidx + -1]->minor.'."';    }
#line 2358 "internal.templateparser.php"
#line 467 "internal.templateparser.y"
    function yy_r146(){$this->_retvalue = '".'.'$_smarty_tpl->getVariable(\''. $this->yystack[$this->yyidx + 0]->minor .'\')->value'.'."'; $this->nocache=$this->template->getVariable(trim($this->yystack[$this->yyidx + 0]->minor,"'"))->nocache;    }
#line 2361 "internal.templateparser.php"
#line 468 "internal.templateparser.y"
    function yy_r147(){preg_match('/\s*/',$this->yystack[$this->yyidx + -2]->minor,$s); $this->_retvalue = $s[0].'".('.$this->yystack[$this->yyidx + -1]->minor.')."';    }
#line 2364 "internal.templateparser.php"
#line 469 "internal.templateparser.y"
    function yy_r148(){ $this->prefix_number++; $this->prefix_code[] = '<?php ob_start();?>'.$this->yystack[$this->yyidx + 0]->minor.'<?php $_tmp'.$this->prefix_number.'=ob_get_clean();?>'; $this->_retvalue = '".$_tmp'.$this->prefix_number.'."';     }
#line 2367 "internal.templateparser.php"
#line 470 "internal.templateparser.y"
    function yy_r149(){$this->_retvalue = '$'.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2370 "internal.templateparser.php"
#line 472 "internal.templateparser.y"
    function yy_r151(){$this->_retvalue = '`'.$this->yystack[$this->yyidx + 0]->minor;    }
#line 2373 "internal.templateparser.php"

    /**
     * placeholder for the left hand side in a reduce operation.
     * 
     * For a parser with a rule like this:
     * <pre>
     * rule(A) ::= B. { A = 1; }
     * </pre>
     * 
     * The parser will translate to something like:
     * 
     * <code>
     * function yy_r0(){$this->_retvalue = 1;}
     * </code>
     */
    private $_retvalue;

    /**
     * Perform a reduce action and the shift that must immediately
     * follow the reduce.
     * 
     * For a rule such as:
     * 
     * <pre>
     * A ::= B blah C. { dosomething(); }
     * </pre>
     * 
     * This function will first call the action, if any, ("dosomething();" in our
     * example), and then it will pop three states from the stack,
     * one for each entry on the right-hand side of the expression
     * (B, blah, and C in our example rule), and then push the result of the action
     * back on to the stack with the resulting state reduced to (as described in the .out
     * file)
     * @param int Number of the rule by which to reduce
     */
    function yy_reduce($yyruleno)
    {
        //int $yygoto;                     /* The next state */
        //int $yyact;                      /* The next action */
        //mixed $yygotominor;        /* The LHS of the rule reduced */
        //TP_yyStackEntry $yymsp;            /* The top of the parser's stack */
        //int $yysize;                     /* Amount to pop the stack */
        $yymsp = $this->yystack[$this->yyidx];
        if (self::$yyTraceFILE && $yyruleno >= 0 
              && $yyruleno < count(self::$yyRuleName)) {
            fprintf(self::$yyTraceFILE, "%sReduce (%d) [%s].\n",
                self::$yyTracePrompt, $yyruleno,
                self::$yyRuleName[$yyruleno]);
        }

        $this->_retvalue = $yy_lefthand_side = null;
        if (array_key_exists($yyruleno, self::$yyReduceMap)) {
            // call the action
            $this->_retvalue = null;
            $this->{'yy_r' . self::$yyReduceMap[$yyruleno]}();
            $yy_lefthand_side = $this->_retvalue;
        }
        $yygoto = self::$yyRuleInfo[$yyruleno]['lhs'];
        $yysize = self::$yyRuleInfo[$yyruleno]['rhs'];
        $this->yyidx -= $yysize;
        for($i = $yysize; $i; $i--) {
            // pop all of the right-hand side parameters
            array_pop($this->yystack);
        }
        $yyact = $this->yy_find_reduce_action($this->yystack[$this->yyidx]->stateno, $yygoto);
        if ($yyact < self::YYNSTATE) {
            /* If we are not debugging and the reduce action popped at least
            ** one element off the stack, then we can push the new element back
            ** onto the stack here, and skip the stack overflow test in yy_shift().
            ** That gives a significant speed improvement. */
            if (!self::$yyTraceFILE && $yysize) {
                $this->yyidx++;
                $x = new TP_yyStackEntry;
                $x->stateno = $yyact;
                $x->major = $yygoto;
                $x->minor = $yy_lefthand_side;
                $this->yystack[$this->yyidx] = $x;
            } else {
                $this->yy_shift($yyact, $yygoto, $yy_lefthand_side);
            }
        } elseif ($yyact == self::YYNSTATE + self::YYNRULE + 1) {
            $this->yy_accept();
        }
    }

    /**
     * The following code executes when the parse fails
     * 
     * Code from %parse_fail is inserted here
     */
    function yy_parse_failed()
    {
        if (self::$yyTraceFILE) {
            fprintf(self::$yyTraceFILE, "%sFail!\n", self::$yyTracePrompt);
        }
        while ($this->yyidx >= 0) {
            $this->yy_pop_parser_stack();
        }
        /* Here code is inserted which will be executed whenever the
        ** parser fails */
    }

    /**
     * The following code executes when a syntax error first occurs.
     * 
     * %syntax_error code is inserted here
     * @param int The major type of the error token
     * @param mixed The minor type of the error token
     */
    function yy_syntax_error($yymajor, $TOKEN)
    {
#line 60 "internal.templateparser.y"

    $this->internalError = true;
    $this->yymajor = $yymajor;
    $this->compiler->trigger_template_error();
#line 2491 "internal.templateparser.php"
    }

    /**
     * The following is executed when the parser accepts
     * 
     * %parse_accept code is inserted here
     */
    function yy_accept()
    {
        if (self::$yyTraceFILE) {
            fprintf(self::$yyTraceFILE, "%sAccept!\n", self::$yyTracePrompt);
        }
        while ($this->yyidx >= 0) {
            $stack = $this->yy_pop_parser_stack();
        }
        /* Here code is inserted which will be executed whenever the
        ** parser accepts */
#line 52 "internal.templateparser.y"

    $this->successful = !$this->internalError;
    $this->internalError = false;
    $this->retvalue = $this->_retvalue;
    //echo $this->retvalue."\n\n";
#line 2516 "internal.templateparser.php"
    }

    /**
     * The main parser program.
     * 
     * The first argument is the major token number.  The second is
     * the token value string as scanned from the input.
     *
     * @param int the token number
     * @param mixed the token value
     * @param mixed any extra arguments that should be passed to handlers
     */
    function doParse($yymajor, $yytokenvalue)
    {
//        $yyact;            /* The parser action. */
//        $yyendofinput;     /* True if we are at the end of input */
        $yyerrorhit = 0;   /* True if yymajor has invoked an error */
        
        /* (re)initialize the parser, if necessary */
        if ($this->yyidx === null || $this->yyidx < 0) {
            /* if ($yymajor == 0) return; // not sure why this was here... */
            $this->yyidx = 0;
            $this->yyerrcnt = -1;
            $x = new TP_yyStackEntry;
            $x->stateno = 0;
            $x->major = 0;
            $this->yystack = array();
            array_push($this->yystack, $x);
        }
        $yyendofinput = ($yymajor==0);
        
        if (self::$yyTraceFILE) {
            fprintf(self::$yyTraceFILE, "%sInput %s\n",
                self::$yyTracePrompt, $this->yyTokenName[$yymajor]);
        }
        
        do {
            $yyact = $this->yy_find_shift_action($yymajor);
            if ($yymajor < self::YYERRORSYMBOL &&
                  !$this->yy_is_expected_token($yymajor)) {
                // force a syntax error
                $yyact = self::YY_ERROR_ACTION;
            }
            if ($yyact < self::YYNSTATE) {
                $this->yy_shift($yyact, $yymajor, $yytokenvalue);
                $this->yyerrcnt--;
                if ($yyendofinput && $this->yyidx >= 0) {
                    $yymajor = 0;
                } else {
                    $yymajor = self::YYNOCODE;
                }
            } elseif ($yyact < self::YYNSTATE + self::YYNRULE) {
                $this->yy_reduce($yyact - self::YYNSTATE);
            } elseif ($yyact == self::YY_ERROR_ACTION) {
                if (self::$yyTraceFILE) {
                    fprintf(self::$yyTraceFILE, "%sSyntax Error!\n",
                        self::$yyTracePrompt);
                }
                if (self::YYERRORSYMBOL) {
                    /* A syntax error has occurred.
                    ** The response to an error depends upon whether or not the
                    ** grammar defines an error token "ERROR".  
                    **
                    ** This is what we do if the grammar does define ERROR:
                    **
                    **  * Call the %syntax_error function.
                    **
                    **  * Begin popping the stack until we enter a state where
                    **    it is legal to shift the error symbol, then shift
                    **    the error symbol.
                    **
                    **  * Set the error count to three.
                    **
                    **  * Begin accepting and shifting new tokens.  No new error
                    **    processing will occur until three tokens have been
                    **    shifted successfully.
                    **
                    */
                    if ($this->yyerrcnt < 0) {
                        $this->yy_syntax_error($yymajor, $yytokenvalue);
                    }
                    $yymx = $this->yystack[$this->yyidx]->major;
                    if ($yymx == self::YYERRORSYMBOL || $yyerrorhit ){
                        if (self::$yyTraceFILE) {
                            fprintf(self::$yyTraceFILE, "%sDiscard input token %s\n",
                                self::$yyTracePrompt, $this->yyTokenName[$yymajor]);
                        }
                        $this->yy_destructor($yymajor, $yytokenvalue);
                        $yymajor = self::YYNOCODE;
                    } else {
                        while ($this->yyidx >= 0 &&
                                 $yymx != self::YYERRORSYMBOL &&
        ($yyact = $this->yy_find_shift_action(self::YYERRORSYMBOL)) >= self::YYNSTATE
                              ){
                            $this->yy_pop_parser_stack();
                        }
                        if ($this->yyidx < 0 || $yymajor==0) {
                            $this->yy_destructor($yymajor, $yytokenvalue);
                            $this->yy_parse_failed();
                            $yymajor = self::YYNOCODE;
                        } elseif ($yymx != self::YYERRORSYMBOL) {
                            $u2 = 0;
                            $this->yy_shift($yyact, self::YYERRORSYMBOL, $u2);
                        }
                    }
                    $this->yyerrcnt = 3;
                    $yyerrorhit = 1;
                } else {
                    /* YYERRORSYMBOL is not defined */
                    /* This is what we do if the grammar does not define ERROR:
                    **
                    **  * Report an error message, and throw away the input token.
                    **
                    **  * If the input token is $, then fail the parse.
                    **
                    ** As before, subsequent error messages are suppressed until
                    ** three input tokens have been successfully shifted.
                    */
                    if ($this->yyerrcnt <= 0) {
                        $this->yy_syntax_error($yymajor, $yytokenvalue);
                    }
                    $this->yyerrcnt = 3;
                    $this->yy_destructor($yymajor, $yytokenvalue);
                    if ($yyendofinput) {
                        $this->yy_parse_failed();
                    }
                    $yymajor = self::YYNOCODE;
                }
            } else {
                $this->yy_accept();
                $yymajor = self::YYNOCODE;
            }            
        } while ($yymajor != self::YYNOCODE && $this->yyidx >= 0);
    }
}
